/*
 * Copyright (C) 2017 Socionext Inc.
 *
 * SPDX-License-Identifier:	GPL-2.0+
#include "stio.h"
#include "reg_stio.h"
 */

#include <linux/io.h>

#include "local-init.h"
#include "stio.h"
#include "reg_stio.h"

typedef struct _umc_addrdata_t{
  u32 addr;
  u32 data;
} umc_addrdata_t;

typedef enum {
	INDEX_OF_UMC_FUNC_INVALID,
	INDEX_OF_UMC_FUNC_CORETEST,
	INDEX_OF_UMC_FUNC_USECASE_HWE,
	INDEX_OF_UMC_FUNC_USECASE_HWE_CMN,
	INDEX_OF_UMC_FUNC_USECASE_PXS3_BDR20G_BASE,
} UMC_FUNCSEL_INDEX;

#define UMC_BASE_SBUS 0x5b600000
#define UMC_BASE_ADDR 0x5b800000
#define UMC_BASE      UMC_BASE_ADDR  /* ߋ̌݊̂߈ꎞIɐ錾B폜 */

#define MAX_CHNUM     3
#define UMC_BASE_(ch)  (UMC_BASE + 0x00200000 * (ch) )

/* reg_umc.h 甲 */

// CA UMC_BASE_(ch) + 0x10XXX
#define UMC_CA_BASE(ch) (UMC_BASE_(ch) + 0x10000)


#define UMC_COMSIZE_16_00_L1_(ch)	(UMC_CA_BASE(ch) + 0xE80)
#define UMC_COMSIZE_16_00_L2_(ch)	(UMC_CA_BASE(ch) + 0xE84)
#define UMC_COMSIZE_16_00_L3_(ch)	(UMC_CA_BASE(ch) + 0xE88)
#define UMC_COMSIZE_16_00_L4_(ch)	(UMC_CA_BASE(ch) + 0xE8C)
#define UMC_COMSIZE_16_00_L5_(ch)	(UMC_CA_BASE(ch) + 0xE90)
#define UMC_COMSIZE_16_00_L6_(ch)	(UMC_CA_BASE(ch) + 0xE94)
#define UMC_COMSIZE_16_00_L7_(ch)	(UMC_CA_BASE(ch) + 0xE98)
#define UMC_COMSIZE_16_00_L8_(ch)	(UMC_CA_BASE(ch) + 0xE9C)
#define UMC_COMSIZE_16_00_L9_(ch)	(UMC_CA_BASE(ch) + 0xEA0)
#define UMC_COMSIZE_16_00_L10_(ch)	(UMC_CA_BASE(ch) + 0xEA4)
#define UMC_COMSIZE_16_00_L11_(ch)	(UMC_CA_BASE(ch) + 0xEA8)
#define UMC_COMSIZE_16_00_L12_(ch)	(UMC_CA_BASE(ch) + 0xEAC)
#define UMC_COMSIZE_16_16_L1_(ch)	(UMC_CA_BASE(ch) + 0xE00)
#define UMC_COMSIZE_16_16_L2_(ch)	(UMC_CA_BASE(ch) + 0xE04)
#define UMC_COMSIZE_16_16_L3_(ch)	(UMC_CA_BASE(ch) + 0xE08)
#define UMC_COMSIZE_16_16_L4_(ch)	(UMC_CA_BASE(ch) + 0xE0C)
#define UMC_COMSIZE_16_16_L5_(ch)	(UMC_CA_BASE(ch) + 0xE10)
#define UMC_COMSIZE_16_16_L6_(ch)	(UMC_CA_BASE(ch) + 0xE14)
#define UMC_COMSIZE_16_16_L7_(ch)	(UMC_CA_BASE(ch) + 0xE18)
#define UMC_COMSIZE_16_16_L8_(ch)	(UMC_CA_BASE(ch) + 0xE1C)
#define UMC_COMSIZE_16_16_L9_(ch)	(UMC_CA_BASE(ch) + 0xE20)
#define UMC_COMSIZE_16_16_L10_(ch)	(UMC_CA_BASE(ch) + 0xE24)
#define UMC_COMSIZE_16_16_L11_(ch)	(UMC_CA_BASE(ch) + 0xE28)
#define UMC_COMSIZE_16_16_L12_(ch)	(UMC_CA_BASE(ch) + 0xE2C)
#define UMC_COMSIZE_16_16_L13_(ch)	(UMC_CA_BASE(ch) + 0xE30)
#define UMC_COMSIZE_16_16_L14_(ch)	(UMC_CA_BASE(ch) + 0xE34)
#define UMC_COMSIZE_16_16_L15_(ch)	(UMC_CA_BASE(ch) + 0xE38)
#define UMC_COMSIZE_16_16_L16_(ch)	(UMC_CA_BASE(ch) + 0xE3C)
#define UMC_COMSIZE_16_16_L17_(ch)	(UMC_CA_BASE(ch) + 0xE40)
#define UMC_COMSIZE_16_16_L18_(ch)	(UMC_CA_BASE(ch) + 0xE44)
#define UMC_COMSIZE_16_16_L19_(ch)	(UMC_CA_BASE(ch) + 0xE48)
#define UMC_COMSIZE_16_16_L20_(ch)	(UMC_CA_BASE(ch) + 0xE4C)
#define UMC_COMSIZE_16_16_L21_(ch)	(UMC_CA_BASE(ch) + 0xE50)
#define UMC_COMSIZE_16_16_L22_(ch)	(UMC_CA_BASE(ch) + 0xE54)
#define UMC_COMSIZE_16_16_L23_(ch)	(UMC_CA_BASE(ch) + 0xE58)
#define UMC_COMSIZE_16_16_L24_(ch)	(UMC_CA_BASE(ch) + 0xE5C)
#define UMC_COMSIZE_16_16_L25_(ch)	(UMC_CA_BASE(ch) + 0xE60)
#define UMC_COMSIZE_16_16_L26_(ch)	(UMC_CA_BASE(ch) + 0xE64)
#define UMC_COMSIZE_16_16_L27_(ch)	(UMC_CA_BASE(ch) + 0xE68)
#define UMC_COMSIZE_16_16_L28_(ch)	(UMC_CA_BASE(ch) + 0xE6C)
#define UMC_COMSIZE_16_16_L29_(ch)	(UMC_CA_BASE(ch) + 0xE70)
#define UMC_COMSIZE_16_16_L30_(ch)	(UMC_CA_BASE(ch) + 0xE74)
#define UMC_COMSIZE_16_16_L31_(ch)	(UMC_CA_BASE(ch) + 0xE78)
#define UMC_COMSIZE_16_16_L32_(ch)	(UMC_CA_BASE(ch) + 0xE7C)
#define UMC_COMSIZE_16_24_L1_(ch)	(UMC_CA_BASE(ch) + 0xEE0)
#define UMC_COMSIZE_16_24_L2_(ch)	(UMC_CA_BASE(ch) + 0xEE4)
#define UMC_COMSIZE_16_24_L3_(ch)	(UMC_CA_BASE(ch) + 0xEE8)
#define UMC_COMSIZE_16_24_L4_(ch)	(UMC_CA_BASE(ch) + 0xEEC)
#define UMC_COMSIZE_16_32_L1_(ch)	(UMC_CA_BASE(ch) + 0xD80)
#define UMC_COMSIZE_16_32_L2_(ch)	(UMC_CA_BASE(ch) + 0xD84)
#define UMC_COMSIZE_16_32_L3_(ch)	(UMC_CA_BASE(ch) + 0xD88)
#define UMC_COMSIZE_16_32_L4_(ch)	(UMC_CA_BASE(ch) + 0xD8C)
#define UMC_COMSIZE_16_32_L5_(ch)	(UMC_CA_BASE(ch) + 0xD90)
#define UMC_COMSIZE_16_32_L6_(ch)	(UMC_CA_BASE(ch) + 0xD94)
#define UMC_COMSIZE_16_32_L7_(ch)	(UMC_CA_BASE(ch) + 0xD98)
#define UMC_COMSIZE_16_32_L8_(ch)	(UMC_CA_BASE(ch) + 0xD9C)
#define UMC_COMSIZE_16_32_L9_(ch)	(UMC_CA_BASE(ch) + 0xDA0)
#define UMC_COMSIZE_16_32_L10_(ch)	(UMC_CA_BASE(ch) + 0xDA4)
#define UMC_COMSIZE_16_32_L11_(ch)	(UMC_CA_BASE(ch) + 0xDA8)
#define UMC_COMSIZE_16_32_L12_(ch)	(UMC_CA_BASE(ch) + 0xDAC)
#define UMC_COMSIZE_16_32_L13_(ch)	(UMC_CA_BASE(ch) + 0xDB0)
#define UMC_COMSIZE_16_32_L14_(ch)	(UMC_CA_BASE(ch) + 0xDB4)
#define UMC_COMSIZE_16_32_L15_(ch)	(UMC_CA_BASE(ch) + 0xDB8)
#define UMC_COMSIZE_16_32_L16_(ch)	(UMC_CA_BASE(ch) + 0xDBC)
#define UMC_COMSIZE_16_32_L17_(ch)	(UMC_CA_BASE(ch) + 0xDC0)
#define UMC_COMSIZE_16_32_L18_(ch)	(UMC_CA_BASE(ch) + 0xDC4)
#define UMC_COMSIZE_16_32_L19_(ch)	(UMC_CA_BASE(ch) + 0xDC8)
#define UMC_COMSIZE_16_32_L20_(ch)	(UMC_CA_BASE(ch) + 0xDCC)
#define UMC_COMSIZE_16_32_L21_(ch)	(UMC_CA_BASE(ch) + 0xDD0)
#define UMC_COMSIZE_16_32_L22_(ch)	(UMC_CA_BASE(ch) + 0xDD4)
#define UMC_COMSIZE_16_32_L23_(ch)	(UMC_CA_BASE(ch) + 0xDD8)
#define UMC_COMSIZE_16_32_L24_(ch)	(UMC_CA_BASE(ch) + 0xDDC)
#define UMC_COMSIZE_16_32_L25_(ch)	(UMC_CA_BASE(ch) + 0xDE0)
#define UMC_COMSIZE_16_32_L26_(ch)	(UMC_CA_BASE(ch) + 0xDE4)
#define UMC_COMSIZE_16_32_L27_(ch)	(UMC_CA_BASE(ch) + 0xDE8)
#define UMC_COMSIZE_16_32_L28_(ch)	(UMC_CA_BASE(ch) + 0xDEC)
#define UMC_COMSIZE_16_32_L29_(ch)	(UMC_CA_BASE(ch) + 0xDF0)
#define UMC_COMSIZE_16_32_L30_(ch)	(UMC_CA_BASE(ch) + 0xDF4)
#define UMC_COMSIZE_16_32_L31_(ch)	(UMC_CA_BASE(ch) + 0xDF8)
#define UMC_COMSIZE_16_32_L32_(ch)	(UMC_CA_BASE(ch) + 0xDFC)
#define UMC_COMSIZE_24_16_L1_(ch)	(UMC_CA_BASE(ch) + 0xF90)
#define UMC_COMSIZE_24_16_L2_(ch)	(UMC_CA_BASE(ch) + 0xF94)
#define UMC_COMSIZE_24_16_L3_(ch)	(UMC_CA_BASE(ch) + 0xF98)
#define UMC_COMSIZE_24_16_L4_(ch)	(UMC_CA_BASE(ch) + 0xF9C)
#define UMC_COMSIZE_24_24_L1_(ch)	(UMC_CA_BASE(ch) + 0xF78)
#define UMC_COMSIZE_24_24_L2_(ch)	(UMC_CA_BASE(ch) + 0xF7C)
#define UMC_COMSIZE_24_24_L3_(ch)	(UMC_CA_BASE(ch) + 0xF80)
#define UMC_COMSIZE_24_24_L4_(ch)	(UMC_CA_BASE(ch) + 0xF84)
#define UMC_COMSIZE_24_32_L1_(ch)	(UMC_CA_BASE(ch) + 0xF60)
#define UMC_COMSIZE_24_32_L2_(ch)	(UMC_CA_BASE(ch) + 0xF64)
#define UMC_COMSIZE_24_32_L3_(ch)	(UMC_CA_BASE(ch) + 0xF68)
#define UMC_COMSIZE_24_32_L4_(ch)	(UMC_CA_BASE(ch) + 0xF6C)
#define UMC_COMSIZE_24_40_L1_(ch)	(UMC_CA_BASE(ch) + 0xF30)
#define UMC_COMSIZE_24_40_L2_(ch)	(UMC_CA_BASE(ch) + 0xF34)
#define UMC_COMSIZE_24_40_L3_(ch)	(UMC_CA_BASE(ch) + 0xF38)
#define UMC_COMSIZE_24_40_L4_(ch)	(UMC_CA_BASE(ch) + 0xF3C)
#define UMC_COMSIZE_32_00_L1_(ch)	(UMC_CA_BASE(ch) + 0xD00)
#define UMC_COMSIZE_32_00_L2_(ch)	(UMC_CA_BASE(ch) + 0xD04)
#define UMC_COMSIZE_32_00_L3_(ch)	(UMC_CA_BASE(ch) + 0xD08)
#define UMC_COMSIZE_32_00_L4_(ch)	(UMC_CA_BASE(ch) + 0xD0C)
#define UMC_COMSIZE_32_00_L5_(ch)	(UMC_CA_BASE(ch) + 0xD10)
#define UMC_COMSIZE_32_00_L6_(ch)	(UMC_CA_BASE(ch) + 0xD14)
#define UMC_COMSIZE_32_00_L7_(ch)	(UMC_CA_BASE(ch) + 0xD18)
#define UMC_COMSIZE_32_00_L8_(ch)	(UMC_CA_BASE(ch) + 0xD1C)
#define UMC_COMSIZE_32_00_L9_(ch)	(UMC_CA_BASE(ch) + 0xD20)
#define UMC_COMSIZE_32_00_L10_(ch)	(UMC_CA_BASE(ch) + 0xD24)
#define UMC_COMSIZE_32_00_L11_(ch)	(UMC_CA_BASE(ch) + 0xD28)
#define UMC_COMSIZE_32_00_L12_(ch)	(UMC_CA_BASE(ch) + 0xD2C)
#define UMC_COMSIZE_32_16_L1_(ch)	(UMC_CA_BASE(ch) + 0xC80)
#define UMC_COMSIZE_32_16_L2_(ch)	(UMC_CA_BASE(ch) + 0xC84)
#define UMC_COMSIZE_32_16_L3_(ch)	(UMC_CA_BASE(ch) + 0xC88)
#define UMC_COMSIZE_32_16_L4_(ch)	(UMC_CA_BASE(ch) + 0xC8C)
#define UMC_COMSIZE_32_16_L5_(ch)	(UMC_CA_BASE(ch) + 0xC90)
#define UMC_COMSIZE_32_16_L6_(ch)	(UMC_CA_BASE(ch) + 0xC94)
#define UMC_COMSIZE_32_16_L7_(ch)	(UMC_CA_BASE(ch) + 0xC98)
#define UMC_COMSIZE_32_16_L8_(ch)	(UMC_CA_BASE(ch) + 0xC9C)
#define UMC_COMSIZE_32_16_L9_(ch)	(UMC_CA_BASE(ch) + 0xCA0)
#define UMC_COMSIZE_32_16_L10_(ch)	(UMC_CA_BASE(ch) + 0xCA4)
#define UMC_COMSIZE_32_16_L11_(ch)	(UMC_CA_BASE(ch) + 0xCA8)
#define UMC_COMSIZE_32_16_L12_(ch)	(UMC_CA_BASE(ch) + 0xCAC)
#define UMC_COMSIZE_32_16_L13_(ch)	(UMC_CA_BASE(ch) + 0xCB0)
#define UMC_COMSIZE_32_16_L14_(ch)	(UMC_CA_BASE(ch) + 0xCB4)
#define UMC_COMSIZE_32_16_L15_(ch)	(UMC_CA_BASE(ch) + 0xCB8)
#define UMC_COMSIZE_32_16_L16_(ch)	(UMC_CA_BASE(ch) + 0xCBC)
#define UMC_COMSIZE_32_16_L17_(ch)	(UMC_CA_BASE(ch) + 0xCC0)
#define UMC_COMSIZE_32_16_L18_(ch)	(UMC_CA_BASE(ch) + 0xCC4)
#define UMC_COMSIZE_32_16_L19_(ch)	(UMC_CA_BASE(ch) + 0xCC8)
#define UMC_COMSIZE_32_16_L20_(ch)	(UMC_CA_BASE(ch) + 0xCCC)
#define UMC_COMSIZE_32_16_L21_(ch)	(UMC_CA_BASE(ch) + 0xCD0)
#define UMC_COMSIZE_32_16_L22_(ch)	(UMC_CA_BASE(ch) + 0xCD4)
#define UMC_COMSIZE_32_16_L23_(ch)	(UMC_CA_BASE(ch) + 0xCD8)
#define UMC_COMSIZE_32_16_L24_(ch)	(UMC_CA_BASE(ch) + 0xCDC)
#define UMC_COMSIZE_32_16_L25_(ch)	(UMC_CA_BASE(ch) + 0xCE0)
#define UMC_COMSIZE_32_16_L26_(ch)	(UMC_CA_BASE(ch) + 0xCE4)
#define UMC_COMSIZE_32_16_L27_(ch)	(UMC_CA_BASE(ch) + 0xCE8)
#define UMC_COMSIZE_32_16_L28_(ch)	(UMC_CA_BASE(ch) + 0xCEC)
#define UMC_COMSIZE_32_16_L29_(ch)	(UMC_CA_BASE(ch) + 0xCF0)
#define UMC_COMSIZE_32_16_L30_(ch)	(UMC_CA_BASE(ch) + 0xCF4)
#define UMC_COMSIZE_32_16_L31_(ch)	(UMC_CA_BASE(ch) + 0xCF8)
#define UMC_COMSIZE_32_16_L32_(ch)	(UMC_CA_BASE(ch) + 0xCFC)
#define UMC_COMSIZE_32_24_L1_(ch)	(UMC_CA_BASE(ch) + 0xD60)
#define UMC_COMSIZE_32_24_L2_(ch)	(UMC_CA_BASE(ch) + 0xD64)
#define UMC_COMSIZE_32_24_L3_(ch)	(UMC_CA_BASE(ch) + 0xD68)
#define UMC_COMSIZE_32_24_L4_(ch)	(UMC_CA_BASE(ch) + 0xD6C)
#define UMC_COMSIZE_32_32_L1_(ch)	(UMC_CA_BASE(ch) + 0xC00)
#define UMC_COMSIZE_32_32_L2_(ch)	(UMC_CA_BASE(ch) + 0xC04)
#define UMC_COMSIZE_32_32_L3_(ch)	(UMC_CA_BASE(ch) + 0xC08)
#define UMC_COMSIZE_32_32_L4_(ch)	(UMC_CA_BASE(ch) + 0xC0C)
#define UMC_COMSIZE_32_32_L5_(ch)	(UMC_CA_BASE(ch) + 0xC10)
#define UMC_COMSIZE_32_32_L6_(ch)	(UMC_CA_BASE(ch) + 0xC14)
#define UMC_COMSIZE_32_32_L7_(ch)	(UMC_CA_BASE(ch) + 0xC18)
#define UMC_COMSIZE_32_32_L8_(ch)	(UMC_CA_BASE(ch) + 0xC1C)
#define UMC_COMSIZE_32_32_L9_(ch)	(UMC_CA_BASE(ch) + 0xC20)
#define UMC_COMSIZE_32_32_L10_(ch)	(UMC_CA_BASE(ch) + 0xC24)
#define UMC_COMSIZE_32_32_L11_(ch)	(UMC_CA_BASE(ch) + 0xC28)
#define UMC_COMSIZE_32_32_L12_(ch)	(UMC_CA_BASE(ch) + 0xC2C)
#define UMC_COMSIZE_32_32_L13_(ch)	(UMC_CA_BASE(ch) + 0xC30)
#define UMC_COMSIZE_32_32_L14_(ch)	(UMC_CA_BASE(ch) + 0xC34)
#define UMC_COMSIZE_32_32_L15_(ch)	(UMC_CA_BASE(ch) + 0xC38)
#define UMC_COMSIZE_32_32_L16_(ch)	(UMC_CA_BASE(ch) + 0xC3C)
#define UMC_COMSIZE_32_32_L17_(ch)	(UMC_CA_BASE(ch) + 0xC40)
#define UMC_COMSIZE_32_32_L18_(ch)	(UMC_CA_BASE(ch) + 0xC44)
#define UMC_COMSIZE_32_32_L19_(ch)	(UMC_CA_BASE(ch) + 0xC48)
#define UMC_COMSIZE_32_32_L20_(ch)	(UMC_CA_BASE(ch) + 0xC4C)
#define UMC_COMSIZE_32_32_L21_(ch)	(UMC_CA_BASE(ch) + 0xC50)
#define UMC_COMSIZE_32_32_L22_(ch)	(UMC_CA_BASE(ch) + 0xC54)
#define UMC_COMSIZE_32_32_L23_(ch)	(UMC_CA_BASE(ch) + 0xC58)
#define UMC_COMSIZE_32_32_L24_(ch)	(UMC_CA_BASE(ch) + 0xC5C)
#define UMC_COMSIZE_32_32_L25_(ch)	(UMC_CA_BASE(ch) + 0xC60)
#define UMC_COMSIZE_32_32_L26_(ch)	(UMC_CA_BASE(ch) + 0xC64)
#define UMC_COMSIZE_32_32_L27_(ch)	(UMC_CA_BASE(ch) + 0xC68)
#define UMC_COMSIZE_32_32_L28_(ch)	(UMC_CA_BASE(ch) + 0xC6C)
#define UMC_COMSIZE_32_32_L29_(ch)	(UMC_CA_BASE(ch) + 0xC70)
#define UMC_COMSIZE_32_32_L30_(ch)	(UMC_CA_BASE(ch) + 0xC74)
#define UMC_COMSIZE_32_32_L31_(ch)	(UMC_CA_BASE(ch) + 0xC78)
#define UMC_COMSIZE_32_32_L32_(ch)	(UMC_CA_BASE(ch) + 0xC7C)
#define UMC_COMSIZE_32_40_L1_(ch)	(UMC_CA_BASE(ch) + 0xF48)
#define UMC_COMSIZE_32_40_L2_(ch)	(UMC_CA_BASE(ch) + 0xF4C)
#define UMC_COMSIZE_32_40_L3_(ch)	(UMC_CA_BASE(ch) + 0xF50)
#define UMC_COMSIZE_32_40_L4_(ch)	(UMC_CA_BASE(ch) + 0xF54)
#define UMC_COMSIZE_40_24_L1_(ch)	(UMC_CA_BASE(ch) + 0xF18)
#define UMC_COMSIZE_40_24_L2_(ch)	(UMC_CA_BASE(ch) + 0xF1C)
#define UMC_COMSIZE_40_24_L3_(ch)	(UMC_CA_BASE(ch) + 0xF20)
#define UMC_COMSIZE_40_24_L4_(ch)	(UMC_CA_BASE(ch) + 0xF24)
#define UMC_COMSIZE_40_40_L1_(ch)	(UMC_CA_BASE(ch) + 0xF00)
#define UMC_COMSIZE_40_40_L2_(ch)	(UMC_CA_BASE(ch) + 0xF04)
#define UMC_COMSIZE_40_40_L3_(ch)	(UMC_CA_BASE(ch) + 0xF08)
#define UMC_COMSIZE_40_40_L4_(ch)	(UMC_CA_BASE(ch) + 0xF0C)
#define UMC_COMSIZE_48_00_L1_(ch)	(UMC_CA_BASE(ch) + 0xFA8)
#define UMC_COMSIZE_48_00_L2_(ch)	(UMC_CA_BASE(ch) + 0xFAC)
#define UMC_COMSIZE_48_00_L3_(ch)	(UMC_CA_BASE(ch) + 0xFB0)
#define UMC_COMSIZE_48_00_L4_(ch)	(UMC_CA_BASE(ch) + 0xFB4)
#define UMC_COMSIZE_1D_L1_(ch)	(UMC_CA_BASE(ch) + 0xFD0)
#define UMC_COMSIZE_1D_L2_(ch)	(UMC_CA_BASE(ch) + 0xFD4)
#define UMC_COMSIZE_1D_L3_(ch)	(UMC_CA_BASE(ch) + 0xFD8)
#define UMC_COMSIZE_1D_L4_(ch)	(UMC_CA_BASE(ch) + 0xFDC)
#define UMC_COMSIZE_1D_L5_(ch)	(UMC_CA_BASE(ch) + 0xFE0)
#define UMC_COMSIZE_1D_L6_(ch)	(UMC_CA_BASE(ch) + 0xFE4)
#define UMC_COMSIZE_1D_L7_(ch)	(UMC_CA_BASE(ch) + 0xFE8)
#define UMC_COMSIZE_1D_L8_(ch)	(UMC_CA_BASE(ch) + 0xFEC)
#define UMC_COMSIZE_1D_L1_(ch)	(UMC_CA_BASE(ch) + 0xFD0)
#define UMC_COMSIZE_1D_L2_(ch)	(UMC_CA_BASE(ch) + 0xFD4)
#define UMC_COMSIZE_1D_L3_(ch)	(UMC_CA_BASE(ch) + 0xFD8)
#define UMC_COMSIZE_1D_L4_(ch)	(UMC_CA_BASE(ch) + 0xFDC)
#define UMC_COMSIZE_1D_L5_(ch)	(UMC_CA_BASE(ch) + 0xFE0)
#define UMC_COMSIZE_1D_L6_(ch)	(UMC_CA_BASE(ch) + 0xFE4)
#define UMC_COMSIZE_1D_L7_(ch)	(UMC_CA_BASE(ch) + 0xFE8)
#define UMC_COMSIZE_1D_L8_(ch)	(UMC_CA_BASE(ch) + 0xFEC)

#define UMC_RATECONT_ICS(ch) (UMC_CA_BASE(ch) + 0x0)
#define UMC_RATECONT_ICA(ch) (UMC_CA_BASE(ch) + 0x4)
#define UMC_RATECONT_ICV(ch) (UMC_CA_BASE(ch) + 0x8)
#define UMC_RATECONT_HDM(ch) (UMC_CA_BASE(ch) + 0xC)
#define UMC_RATECONT_MDM(ch) (UMC_CA_BASE(ch) + 0x10)
#define UMC_RATECONT_HDD(ch) (UMC_CA_BASE(ch) + 0x14)
#define UMC_RATECONT_MDD(ch) (UMC_CA_BASE(ch) + 0x18)
#define UMC_RATECONT_SIO(ch) (UMC_CA_BASE(ch) + 0x1C)
#define UMC_RATECONT_GIO(ch) (UMC_CA_BASE(ch) + 0x20)
#define UMC_RATECONT_VO1(ch) (UMC_CA_BASE(ch) + 0x24)
#define UMC_RATECONT_VO2(ch) (UMC_CA_BASE(ch) + 0x28)
#define UMC_RATECONT_VO0(ch) (UMC_CA_BASE(ch) + 0x2C)
#define UMC_RATECONT_VDV(ch) (UMC_CA_BASE(ch) + 0x30)
#define UMC_RATECONT_VPE(ch) (UMC_CA_BASE(ch) + 0x34)
#define UMC_RATECONT_RG0(ch) (UMC_CA_BASE(ch) + 0x38)
#define UMC_RATECONT_GR0(ch) (UMC_CA_BASE(ch) + 0x3C)
#define UMC_RATECONT_VG2(ch) (UMC_CA_BASE(ch) + 0x40)
#define UMC_RATECONT_PCI(ch) (UMC_CA_BASE(ch) + 0x44)
#define UMC_RATECONT_AIO(ch) (UMC_CA_BASE(ch) + 0x48)
#define UMC_RATECONT_VDM(ch) (UMC_CA_BASE(ch) + 0x4C)
#define UMC_RATECONT_REF(ch) (UMC_CA_BASE(ch) + 0x50)
#define UMC_RATECONT_IDS(ch) (UMC_CA_BASE(ch) + 0x54)
#define UMC_RATECONT_ID2(ch) (UMC_CA_BASE(ch) + 0x58)
#define UMC_RATECONT_IXM(ch) (UMC_CA_BASE(ch) + 0x5C)
#define UMC_RATECONT_VDC(ch) (UMC_CA_BASE(ch) + 0x60)
#define UMC_RATECONT_VDW(ch) (UMC_CA_BASE(ch) + 0x64)
#define UMC_RATECONT_VW2(ch) (UMC_CA_BASE(ch) + 0x68)
#define UMC_RATECONT_AR0(ch) (UMC_CA_BASE(ch) + 0x6C)
#define UMC_RATECONT_PXT(ch) (UMC_CA_BASE(ch) + 0x70)
#define UMC_RATECONT_PXW(ch) (UMC_CA_BASE(ch) + 0x74)
#define UMC_RATECONT_PXR(ch) (UMC_CA_BASE(ch) + 0x78)

#define UMC_MASTEROPTION_ICS(ch) (UMC_CA_BASE(ch) + 0x200)
#define UMC_MASTEROPTION_ICA(ch) (UMC_CA_BASE(ch) + 0x204)
#define UMC_MASTEROPTION_ICV(ch) (UMC_CA_BASE(ch) + 0x208)
#define UMC_MASTEROPTION_HDM(ch) (UMC_CA_BASE(ch) + 0x20C)
#define UMC_MASTEROPTION_MDM(ch) (UMC_CA_BASE(ch) + 0x210)
#define UMC_MASTEROPTION_HDD(ch) (UMC_CA_BASE(ch) + 0x214)
#define UMC_MASTEROPTION_MDD(ch) (UMC_CA_BASE(ch) + 0x218)
#define UMC_MASTEROPTION_SIO(ch) (UMC_CA_BASE(ch) + 0x21C)
#define UMC_MASTEROPTION_GIO(ch) (UMC_CA_BASE(ch) + 0x220)
#define UMC_MASTEROPTION_VO1(ch) (UMC_CA_BASE(ch) + 0x224)
#define UMC_MASTEROPTION_VO2(ch) (UMC_CA_BASE(ch) + 0x228)
#define UMC_MASTEROPTION_VO0(ch) (UMC_CA_BASE(ch) + 0x22C)
#define UMC_MASTEROPTION_VDV(ch) (UMC_CA_BASE(ch) + 0x230)
#define UMC_MASTEROPTION_VPE(ch) (UMC_CA_BASE(ch) + 0x234)
#define UMC_MASTEROPTION_RG0(ch) (UMC_CA_BASE(ch) + 0x238)
#define UMC_MASTEROPTION_GR0(ch) (UMC_CA_BASE(ch) + 0x23C)
#define UMC_MASTEROPTION_VG2(ch) (UMC_CA_BASE(ch) + 0x240)
#define UMC_MASTEROPTION_PCI(ch) (UMC_CA_BASE(ch) + 0x244)
#define UMC_MASTEROPTION_AIO(ch) (UMC_CA_BASE(ch) + 0x248)
#define UMC_MASTEROPTION_VDM(ch) (UMC_CA_BASE(ch) + 0x24C)
#define UMC_MASTEROPTION_REF(ch) (UMC_CA_BASE(ch) + 0x250)
#define UMC_MASTEROPTION_IDS(ch) (UMC_CA_BASE(ch) + 0x254)
#define UMC_MASTEROPTION_ID2(ch) (UMC_CA_BASE(ch) + 0x258)
#define UMC_MASTEROPTION_IXM(ch) (UMC_CA_BASE(ch) + 0x25C)
#define UMC_MASTEROPTION_VDC(ch) (UMC_CA_BASE(ch) + 0x260)
#define UMC_MASTEROPTION_VDW(ch) (UMC_CA_BASE(ch) + 0x264)
#define UMC_MASTEROPTION_VW2(ch) (UMC_CA_BASE(ch) + 0x268)
#define UMC_MASTEROPTION_AR0(ch) (UMC_CA_BASE(ch) + 0x26C)
#define UMC_MASTEROPTION_PXT(ch) (UMC_CA_BASE(ch) + 0x270)
#define UMC_MASTEROPTION_PXW(ch) (UMC_CA_BASE(ch) + 0x274)
#define UMC_MASTEROPTION_PXR(ch) (UMC_CA_BASE(ch) + 0x278)

#define UMC_PRIORITY_ICS(ch) (UMC_CA_BASE(ch) + 0x400)
#define UMC_PRIORITY_ICA(ch) (UMC_CA_BASE(ch) + 0x404)
#define UMC_PRIORITY_ICV(ch) (UMC_CA_BASE(ch) + 0x408)
#define UMC_PRIORITY_HDM(ch) (UMC_CA_BASE(ch) + 0x40C)
#define UMC_PRIORITY_MDM(ch) (UMC_CA_BASE(ch) + 0x410)
#define UMC_PRIORITY_HDD(ch) (UMC_CA_BASE(ch) + 0x414)
#define UMC_PRIORITY_MDD(ch) (UMC_CA_BASE(ch) + 0x418)
#define UMC_PRIORITY_SIO(ch) (UMC_CA_BASE(ch) + 0x41C)
#define UMC_PRIORITY_GIO(ch) (UMC_CA_BASE(ch) + 0x420)
#define UMC_PRIORITY_VO1(ch) (UMC_CA_BASE(ch) + 0x424)
#define UMC_PRIORITY_VO2(ch) (UMC_CA_BASE(ch) + 0x428)
#define UMC_PRIORITY_VO0(ch) (UMC_CA_BASE(ch) + 0x42C)
#define UMC_PRIORITY_VDV(ch) (UMC_CA_BASE(ch) + 0x430)
#define UMC_PRIORITY_VPE(ch) (UMC_CA_BASE(ch) + 0x434)
#define UMC_PRIORITY_RG0(ch) (UMC_CA_BASE(ch) + 0x438)
#define UMC_PRIORITY_GR0(ch) (UMC_CA_BASE(ch) + 0x43C)
#define UMC_PRIORITY_VG2(ch) (UMC_CA_BASE(ch) + 0x440)
#define UMC_PRIORITY_PCI(ch) (UMC_CA_BASE(ch) + 0x444)
#define UMC_PRIORITY_AIO(ch) (UMC_CA_BASE(ch) + 0x448)
#define UMC_PRIORITY_VDM(ch) (UMC_CA_BASE(ch) + 0x44C)
#define UMC_PRIORITY_REF(ch) (UMC_CA_BASE(ch) + 0x450)
#define UMC_PRIORITY_IDS(ch) (UMC_CA_BASE(ch) + 0x454)
#define UMC_PRIORITY_ID2(ch) (UMC_CA_BASE(ch) + 0x458)
#define UMC_PRIORITY_IXM(ch) (UMC_CA_BASE(ch) + 0x45C)
#define UMC_PRIORITY_VDC(ch) (UMC_CA_BASE(ch) + 0x460)
#define UMC_PRIORITY_VDW(ch) (UMC_CA_BASE(ch) + 0x464)
#define UMC_PRIORITY_VW2(ch) (UMC_CA_BASE(ch) + 0x468)
#define UMC_PRIORITY_AR0(ch) (UMC_CA_BASE(ch) + 0x46C)
#define UMC_PRIORITY_PXT(ch) (UMC_CA_BASE(ch) + 0x470)
#define UMC_PRIORITY_PXW(ch) (UMC_CA_BASE(ch) + 0x474)
#define UMC_PRIORITY_PXR(ch) (UMC_CA_BASE(ch) + 0x478)

// NIC-B
#define UMC_SD_EMMC_CHSEL (UMC_BASE_SBUS + 0x4014)

#define UMC_CHSEL_CPU (UMC_BASE_SBUS + 0x0054) /* for hijack test */
#define UMC_CHSEL_HDM (UMC_BASE_SBUS + 0x0C54)
#define UMC_CHSEL_MDM (UMC_BASE_SBUS + 0x0E54)
#define UMC_CHSEL_VDM (UMC_BASE_SBUS + 0x3A54)

//extra
#define UMC_FUNC_DATA_END (0xffff)

// DC UMC_BASE_(ch) + 0x11XXX
#define UMC_DC_BASE(ch)		(UMC_BASE_(ch) + 0x11000)

#define UMCDEBUGD(ch)   (UMC_DC_BASE(ch) + 0x71C)
#define UMC_RATE_CHANGE(ch) (UMC_CA_BASE(ch) + 0xA00)
#define UMC_RATE_CHANGE(ch) (UMC_CA_BASE(ch) + 0xA00)
#define UMC_DIR_ARB(ch)      (UMC_CA_BASE(ch) + 0xA90)
#define UMC_BNK_ARB_MODE(ch) (UMC_CA_BASE(ch) + 0xA94)


/* functable , funcselRs[ */

static const umc_addrdata_t comsize_table_pxs2_ld6b_freq2133[] = {
  /*** For DDR3-CH0 ***/
    {UMC_COMSIZE_16_00_L1_(0),	0x04801116}, /*lsz=04, cls=00, pin=0, ett=1, dir=r, CH=1, oh=360.86 (=> setval=22)*/
    {UMC_COMSIZE_16_00_L2_(0),	0x08801117}, /*lsz=08, cls=00, pin=0, ett=1, dir=r, CH=1, oh=378.12 (=> setval=23)*/
    {UMC_COMSIZE_16_00_L3_(0),	0x09801116}, /*lsz=09, cls=00, pin=0, ett=1, dir=r, CH=1, oh=344.00 (=> setval=22) for hdm*/
    {UMC_COMSIZE_16_00_L4_(0),	0x0b801418}, /*lsz=11, cls=00, pin=0, ett=4, dir=r, CH=1, oh=398.73 (=> setval=24)*/
    {UMC_COMSIZE_16_00_L5_(0),	0x0c801519}, /*lsz=12, cls=00, pin=0, ett=5, dir=r, CH=1, oh=415.52 (=> setval=25)*/
    {UMC_COMSIZE_16_00_L6_(0),	0x0f80151d}, /*lsz=15, cls=00, pin=0, ett=5, dir=r, CH=1, oh=474.22 (=> setval=29)*/
    {UMC_COMSIZE_16_00_L7_(0),	0x1080151e}, /*lsz=16, cls=00, pin=0, ett=5, dir=r, CH=1, oh=490.12 (=> setval=30)*/
    {UMC_COMSIZE_16_00_L8_(0),	0x10001d21}, /*lsz=16, cls=00, pin=0, ett=13, dir=w, CH=1, oh=528.0 (=> setval=33)*/
    {UMC_COMSIZE_16_00_L9_(0),	0x13801621}, /*lsz=19, cls=00, pin=0, ett=6, dir=r, CH=1, oh=537.71 (=> setval=33)*/
    {UMC_COMSIZE_16_00_L10_(0),	0x17801525}, /*lsz=23, cls=00, pin=0, ett=5, dir=r, CH=1, oh=600.8 (=> setval=37)*/
    {UMC_COMSIZE_16_00_L11_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_00_L12_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L1_(0),	0x84821117}, /*lsz=04, cls=02, pin=1, ett=1, dir=r, CH=1, oh=379.88 (=> setval=23)*/
    {UMC_COMSIZE_16_16_L2_(0),	0x8884171a}, /*lsz=08, cls=04, pin=1, ett=7, dir=r, CH=1, oh=419.84 (=> setval=26)*/
    {UMC_COMSIZE_16_16_L3_(0),	0x8b851a1d}, /*lsz=11, cls=05, pin=1, ett=10, dir=r, CH=1, oh=466.45 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L4_(0),	0x8c861b1e}, /*lsz=12, cls=06, pin=1, ett=11, dir=r, CH=1, oh=490.67 (=> setval=30)*/
    {UMC_COMSIZE_16_16_L5_(0),	0x8f871c22}, /*lsz=15, cls=07, pin=1, ett=12, dir=r, CH=1, oh=548.11 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L6_(0),	0x90881d20}, /*lsz=16, cls=08, pin=1, ett=13, dir=r, CH=1, oh=575.35 (=> setval=35) for hdd*/
    {UMC_COMSIZE_16_16_L7_(0),	0x93891e27}, /*lsz=19, cls=09, pin=1, ett=14, dir=r, CH=1, oh=633.0 (=> setval=39)*/
    {UMC_COMSIZE_16_16_L8_(0),	0x978b1d2c}, /*lsz=23, cls=11, pin=1, ett=13, dir=r, CH=1, oh=711.8 (=> setval=44)*/
    {UMC_COMSIZE_16_16_L9_(0),	0x04851318}, /*lsz=04, cls=05, pin=0, ett=3, dir=r, CH=1, oh=397.43 (=> setval=24)*/
    {UMC_COMSIZE_16_16_L10_(0),	0x0b851a1d}, /*lsz=11, cls=05, pin=0, ett=10, dir=r, CH=1, oh=466.45 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L11_(0),	0x04871519}, /*lsz=04, cls=07, pin=0, ett=5, dir=r, CH=1, oh=413.69 (=> setval=25)*/
    {UMC_COMSIZE_16_16_L12_(0),	0x0887191c}, /*lsz=08, cls=07, pin=0, ett=9, dir=r, CH=1, oh=448.58 (=> setval=28)*/
    {UMC_COMSIZE_16_16_L13_(0),	0x0f821820}, /*lsz=15, cls=02, pin=0, ett=8, dir=r, CH=1, oh=512.22 (=> setval=32)*/
    {UMC_COMSIZE_16_16_L14_(0),	0x0f871c22}, /*lsz=15, cls=07, pin=0, ett=12, dir=r, CH=1, oh=548.11 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L15_(0),	0x08891b1d}, /*lsz=08, cls=09, pin=0, ett=11, dir=r, CH=1, oh=469.38 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L16_(0),	0x0c891d20}, /*lsz=12, cls=09, pin=0, ett=13, dir=r, CH=1, oh=524.57 (=> setval=32)*/
    {UMC_COMSIZE_16_16_L17_(0),	0x13821923}, /*lsz=19, cls=02, pin=0, ett=9, dir=r, CH=1, oh=575.71 (=> setval=35)*/
    {UMC_COMSIZE_16_16_L18_(0),	0x13841c24}, /*lsz=19, cls=04, pin=0, ett=12, dir=r, CH=1, oh=588.57 (=> setval=36)*/
    {UMC_COMSIZE_16_16_L19_(0),	0x13891e27}, /*lsz=19, cls=09, pin=0, ett=14, dir=r, CH=1, oh=633.0 (=> setval=39)*/
    {UMC_COMSIZE_16_16_L20_(0),	0x0c8b1d22}, /*lsz=12, cls=11, pin=0, ett=13, dir=r, CH=1, oh=545.86 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L21_(0),	0x108b1d26}, /*lsz=16, cls=11, pin=0, ett=13, dir=r, CH=1, oh=608.29 (=> setval=38)*/
    {UMC_COMSIZE_16_16_L22_(0),	0x17841b28}, /*lsz=23, cls=04, pin=0, ett=11, dir=r, CH=1, oh=649.6 (=> setval=40)*/
    {UMC_COMSIZE_16_16_L23_(0),	0x17861c29}, /*lsz=23, cls=06, pin=0, ett=12, dir=r, CH=1, oh=665.8 (=> setval=41)*/
    {UMC_COMSIZE_16_16_L24_(0),	0x178b1d2c}, /*lsz=23, cls=11, pin=0, ett=13, dir=r, CH=1, oh=711.8 (=> setval=44)*/
    {UMC_COMSIZE_16_16_L25_(0),	0x10081030}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1026.0 (=> setval=64) for hdd */
    {UMC_COMSIZE_16_16_L26_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L27_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L28_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L29_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L30_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L31_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L32_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L1_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L1_(0),	0x8482111b}, /*lsz=04, cls=02, pin=1, ett=1, dir=r, CH=1, oh=438.6 (=> setval=27)*/
    {UMC_COMSIZE_16_32_L2_(0),	0x8884161f}, /*lsz=08, cls=04, pin=1, ett=6, dir=r, CH=1, oh=509.6 (=> setval=31)*/
    {UMC_COMSIZE_16_32_L3_(0),	0x8b851823}, /*lsz=11, cls=05, pin=1, ett=8, dir=r, CH=1, oh=569.11 (=> setval=35)*/
    {UMC_COMSIZE_16_32_L4_(0),	0x8c861826}, /*lsz=12, cls=06, pin=1, ett=8, dir=r, CH=1, oh=620.94 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L5_(0),	0x8f87182b}, /*lsz=15, cls=07, pin=1, ett=8, dir=r, CH=1, oh=702.82 (=> setval=43)*/
    {UMC_COMSIZE_16_32_L6_(0),	0x9088182e}, /*lsz=16, cls=08, pin=1, ett=8, dir=r, CH=1, oh=745.43 (=> setval=46)*/
    {UMC_COMSIZE_16_32_L7_(0),	0x93891a33}, /*lsz=19, cls=09, pin=1, ett=10, dir=r, CH=1, oh=820.9 (=> setval=51)*/
    {UMC_COMSIZE_16_32_L8_(0),	0x978b173b}, /*lsz=23, cls=11, pin=1, ett=7, dir=r, CH=1, oh=953.29 (=> setval=59)*/
    {UMC_COMSIZE_16_32_L9_(0),	0x04851121}, /*lsz=04, cls=05, pin=0, ett=1, dir=r, CH=1, oh=529.33 (=> setval=33)*/
    {UMC_COMSIZE_16_32_L10_(0),	0x0b851823}, /*lsz=11, cls=05, pin=0, ett=8, dir=r, CH=1, oh=569.11 (=> setval=35)*/
    {UMC_COMSIZE_16_32_L11_(0),	0x04871125}, /*lsz=04, cls=07, pin=0, ett=1, dir=r, CH=1, oh=598.76 (=> setval=37)*/
    {UMC_COMSIZE_16_32_L12_(0),	0x08871426}, /*lsz=08, cls=07, pin=0, ett=4, dir=r, CH=1, oh=620.36 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L13_(0),	0x0f821922}, /*lsz=15, cls=02, pin=0, ett=9, dir=r, CH=1, oh=553.39 (=> setval=34)*/
    {UMC_COMSIZE_16_32_L14_(0),	0x0f87182b}, /*lsz=15, cls=07, pin=0, ett=8, dir=r, CH=1, oh=702.82 (=> setval=43)*/
    {UMC_COMSIZE_16_32_L15_(0),	0x0889132c}, /*lsz=08, cls=09, pin=0, ett=3, dir=r, CH=1, oh=707.64 (=> setval=44)*/
    {UMC_COMSIZE_16_32_L16_(0),	0x0c89152e}, /*lsz=12, cls=09, pin=0, ett=5, dir=r, CH=1, oh=751.0 (=> setval=46)*/
    {UMC_COMSIZE_16_32_L17_(0),	0x13821b26}, /*lsz=19, cls=02, pin=0, ett=11, dir=r, CH=1, oh=613.71 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L18_(0),	0x13841e29}, /*lsz=19, cls=04, pin=0, ett=14, dir=r, CH=1, oh=660.86 (=> setval=41)*/
    {UMC_COMSIZE_16_32_L19_(0),	0x13891a33}, /*lsz=19, cls=09, pin=0, ett=10, dir=r, CH=1, oh=820.9 (=> setval=51)*/
    {UMC_COMSIZE_16_32_L20_(0),	0x0c8b1334}, /*lsz=12, cls=11, pin=0, ett=3, dir=r, CH=1, oh=837.62 (=> setval=52)*/
    {UMC_COMSIZE_16_32_L21_(0),	0x108b1537}, /*lsz=16, cls=11, pin=0, ett=5, dir=r, CH=1, oh=883.53 (=> setval=55)*/
    {UMC_COMSIZE_16_32_L22_(0),	0x17841e2c}, /*lsz=23, cls=04, pin=0, ett=14, dir=r, CH=1, oh=717.6 (=> setval=44)*/
    {UMC_COMSIZE_16_32_L23_(0),	0x17861c30}, /*lsz=23, cls=06, pin=0, ett=12, dir=r, CH=1, oh=769.51 (=> setval=48)*/
    {UMC_COMSIZE_16_32_L24_(0),	0x178b173b}, /*lsz=23, cls=11, pin=0, ett=7, dir=r, CH=1, oh=953.29 (=> setval=59)*/
    {UMC_COMSIZE_16_32_L25_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L26_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L27_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L28_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L29_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L30_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L31_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L32_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L1_(0),	0x10081c37}, /*lsz=16, cls=08, pin=0, ett=12, dir=w, CH=1, oh=883.0 (=> setval=55)*/
    {UMC_COMSIZE_24_16_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L1_(0),	0x10081156}, /*lsz=16, cls=08, pin=0, ett=1, dir=w, CH=1, oh=1386.25 (=> setval=86)*/
    {UMC_COMSIZE_24_24_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L1_(0),	0x10081a3e}, /*lsz=16, cls=08, pin=0, ett=10, dir=w, CH=1, oh=1003.0 (=> setval=62)*/
    {UMC_COMSIZE_24_32_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L1_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_00_L1_(0),	0x04801119}, /*lsz=04, cls=00, pin=0, ett=1, dir=r, CH=1, oh=401.13 (=> setval=25)*/
    {UMC_COMSIZE_32_00_L2_(0),	0x05801715}, /*lsz=05, cls=00, pin=0, ett=7, dir=r, CH=1, oh=332.00 (=> setval=21) for hdm*/
    {UMC_COMSIZE_32_00_L3_(0),	0x08801718}, /*lsz=08, cls=00, pin=0, ett=7, dir=r, CH=1, oh=484.05 (=> setval=30) for hdd*/
    {UMC_COMSIZE_32_00_L4_(0),	0x0980171c}, /*lsz=09, cls=00, pin=0, ett=7, dir=r, CH=1, oh=436.00 (=> setval=28) for hdm*/
    {UMC_COMSIZE_32_00_L5_(0),	0x0b801723}, /*lsz=11, cls=00, pin=0, ett=7, dir=r, CH=1, oh=570.3  (=> setval=35)*/
    {UMC_COMSIZE_32_00_L6_(0),	0x0c801825}, /*lsz=12, cls=00, pin=0, ett=8, dir=r, CH=1, oh=603.49 (=> setval=37)*/
    {UMC_COMSIZE_32_00_L7_(0),	0x0f80172c}, /*lsz=15, cls=00, pin=0, ett=7, dir=r, CH=1, oh=705.78 (=> setval=44)*/
    {UMC_COMSIZE_32_00_L8_(0),	0x1080172e}, /*lsz=16, cls=00, pin=0, ett=7, dir=r, CH=1, oh=737.57 (=> setval=46)*/
    {UMC_COMSIZE_32_00_L9_(0),	0x10001040}, /*lsz=16, cls=00, pin=0, ett=0, dir=w, CH=1, oh=1037.0 (=> setval=64)*/
    {UMC_COMSIZE_32_00_L10_(0),	0x13801734}, /*lsz=19, cls=00, pin=0, ett=7, dir=r, CH=1, oh=832.76 (=> setval=52)*/
    {UMC_COMSIZE_32_00_L11_(0),	0x1780153b}, /*lsz=23, cls=00, pin=0, ett=5, dir=r, CH=1, oh=958.93 (=> setval=59)*/
    {UMC_COMSIZE_32_00_L12_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L1_(0),	0x8482141a}, /*lsz=04, cls=02, pin=1, ett=4, dir=r, CH=1, oh=425.34 (=> setval=26)*/
    {UMC_COMSIZE_32_16_L2_(0),	0x88841722}, /*lsz=08, cls=04, pin=1, ett=7, dir=r, CH=1, oh=550.63 (=> setval=34)*/
    {UMC_COMSIZE_32_16_L3_(0),	0x8b851729}, /*lsz=11, cls=05, pin=1, ett=7, dir=r, CH=1, oh=656.45 (=> setval=41)*/
    {UMC_COMSIZE_32_16_L4_(0),	0x8c86182b}, /*lsz=12, cls=06, pin=1, ett=8, dir=r, CH=1, oh=699.68 (=> setval=43)*/
    {UMC_COMSIZE_32_16_L5_(0),	0x8f871732}, /*lsz=15, cls=07, pin=1, ett=7, dir=r, CH=1, oh=807.78 (=> setval=50)*/
    {UMC_COMSIZE_32_16_L6_(0),	0x90881835}, /*lsz=16, cls=08, pin=1, ett=8, dir=r, CH=1, oh=853.06 (=> setval=53)*/
    {UMC_COMSIZE_32_16_L7_(0),	0x9389183c}, /*lsz=19, cls=09, pin=1, ett=8, dir=r, CH=1, oh=961.05 (=> setval=60)*/
    {UMC_COMSIZE_32_16_L8_(0),	0x978b1645}, /*lsz=23, cls=11, pin=1, ett=6, dir=r, CH=1, oh=1106.53 (=> setval=69)*/
    {UMC_COMSIZE_32_16_L9_(0),	0x0485151c}, /*lsz=04, cls=05, pin=0, ett=5, dir=r, CH=1, oh=453.83 (=> setval=28)*/
    {UMC_COMSIZE_32_16_L10_(0),	0x0b851729}, /*lsz=11, cls=05, pin=0, ett=7, dir=r, CH=1, oh=656.45 (=> setval=41)*/
    {UMC_COMSIZE_32_16_L11_(0),	0x0487161d}, /*lsz=04, cls=07, pin=0, ett=6, dir=r, CH=1, oh=472.57 (=> setval=29)*/
    {UMC_COMSIZE_32_16_L12_(0),	0x08871924}, /*lsz=08, cls=07, pin=0, ett=9, dir=r, CH=1, oh=584.93 (=> setval=36)*/
    {UMC_COMSIZE_32_16_L13_(0),	0x0f82162f}, /*lsz=15, cls=02, pin=0, ett=6, dir=r, CH=1, oh=757.78 (=> setval=47)*/
    {UMC_COMSIZE_32_16_L14_(0),	0x0f871732}, /*lsz=15, cls=07, pin=0, ett=7, dir=r, CH=1, oh=807.78 (=> setval=50)*/
    {UMC_COMSIZE_32_16_L15_(0),	0x08891926}, /*lsz=08, cls=09, pin=0, ett=9, dir=r, CH=1, oh=610.41 (=> setval=38)*/
    {UMC_COMSIZE_32_16_L16_(0),	0x0c89192e}, /*lsz=12, cls=09, pin=0, ett=9, dir=r, CH=1, oh=738.95 (=> setval=46)*/
    {UMC_COMSIZE_32_16_L17_(0),	0x13821737}, /*lsz=19, cls=02, pin=0, ett=7, dir=r, CH=1, oh=884.76 (=> setval=55)*/
    {UMC_COMSIZE_32_16_L18_(0),	0x13841738}, /*lsz=19, cls=04, pin=0, ett=7, dir=r, CH=1, oh=905.52 (=> setval=56)*/
    {UMC_COMSIZE_32_16_L19_(0),	0x1389183c}, /*lsz=19, cls=09, pin=0, ett=8, dir=r, CH=1, oh=961.05 (=> setval=60)*/
    {UMC_COMSIZE_32_16_L20_(0),	0x0c8b192f}, /*lsz=12, cls=11, pin=0, ett=9, dir=r, CH=1, oh=763.4 (=> setval=47)*/
    {UMC_COMSIZE_32_16_L21_(0),	0x108b1937}, /*lsz=16, cls=11, pin=0, ett=9, dir=r, CH=1, oh=890.71 (=> setval=55)*/
    {UMC_COMSIZE_32_16_L22_(0),	0x17841540}, /*lsz=23, cls=04, pin=0, ett=5, dir=r, CH=1, oh=1028.8 (=> setval=64)*/
    {UMC_COMSIZE_32_16_L23_(0),	0x17861641}, /*lsz=23, cls=06, pin=0, ett=6, dir=r, CH=1, oh=1050.27 (=> setval=65)*/
    {UMC_COMSIZE_32_16_L24_(0),	0x178b1645}, /*lsz=23, cls=11, pin=0, ett=6, dir=r, CH=1, oh=1106.53 (=> setval=69)*/
    {UMC_COMSIZE_32_16_L25_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L26_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L27_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L28_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L29_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L30_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L31_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L32_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L1_(0),	0x1008105e}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1514.38 (=> setval=94)*/
    {UMC_COMSIZE_32_24_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L1_(0),	0x8482131d}, /*lsz=04, cls=02, pin=1, ett=3, dir=r, CH=1, oh=478.14 (=> setval=29)*/
    {UMC_COMSIZE_32_32_L2_(0),	0x88841627}, /*lsz=08, cls=04, pin=1, ett=6, dir=r, CH=1, oh=635.37 (=> setval=39)*/
    {UMC_COMSIZE_32_32_L3_(0),	0x8b85152e}, /*lsz=11, cls=05, pin=1, ett=5, dir=r, CH=1, oh=750.52 (=> setval=46)*/
    {UMC_COMSIZE_32_32_L4_(0),	0x8c861633}, /*lsz=12, cls=06, pin=1, ett=6, dir=r, CH=1, oh=816.17 (=> setval=51)*/
    {UMC_COMSIZE_32_32_L5_(0),	0x8f87153a}, /*lsz=15, cls=07, pin=1, ett=5, dir=r, CH=1, oh=933.56 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L6_(0),	0x9088153f}, /*lsz=16, cls=08, pin=1, ett=5, dir=r, CH=1, oh=1011.02 (=> setval=63)*/
    {UMC_COMSIZE_32_32_L7_(0),	0x93891546}, /*lsz=19, cls=09, pin=1, ett=5, dir=r, CH=1, oh=1132.67 (=> setval=70)*/
    {UMC_COMSIZE_32_32_L8_(0),	0x978b1351}, /*lsz=23, cls=11, pin=1, ett=3, dir=r, CH=1, oh=1311.87 (=> setval=81)*/
    {UMC_COMSIZE_32_32_L9_(0),	0x04851324}, /*lsz=04, cls=05, pin=0, ett=3, dir=r, CH=1, oh=587.21 (=> setval=36)*/
    {UMC_COMSIZE_32_32_L10_(0),	0x0b85152e}, /*lsz=11, cls=05, pin=0, ett=5, dir=r, CH=1, oh=750.52 (=> setval=46)*/
    {UMC_COMSIZE_32_32_L11_(0),	0x04871229}, /*lsz=04, cls=07, pin=0, ett=2, dir=r, CH=1, oh=664.35 (=> setval=41)*/
    {UMC_COMSIZE_32_32_L12_(0),	0x0887142f}, /*lsz=08, cls=07, pin=0, ett=4, dir=r, CH=1, oh=758.29 (=> setval=47)*/
    {UMC_COMSIZE_32_32_L13_(0),	0x0f821632}, /*lsz=15, cls=02, pin=0, ett=6, dir=r, CH=1, oh=804.44 (=> setval=50)*/
    {UMC_COMSIZE_32_32_L14_(0),	0x0f87153a}, /*lsz=15, cls=07, pin=0, ett=5, dir=r, CH=1, oh=933.56 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L15_(0),	0x08891334}, /*lsz=08, cls=09, pin=0, ett=3, dir=r, CH=1, oh=846.77 (=> setval=52)*/
    {UMC_COMSIZE_32_32_L16_(0),	0x0c89143c}, /*lsz=12, cls=09, pin=0, ett=4, dir=r, CH=1, oh=961.38 (=> setval=60)*/
    {UMC_COMSIZE_32_32_L17_(0),	0x1382163a}, /*lsz=19, cls=02, pin=0, ett=6, dir=r, CH=1, oh=931.43 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L18_(0),	0x1384163d}, /*lsz=19, cls=04, pin=0, ett=6, dir=r, CH=1, oh=987.24 (=> setval=61)*/
    {UMC_COMSIZE_32_32_L19_(0),	0x13891546}, /*lsz=19, cls=09, pin=0, ett=5, dir=r, CH=1, oh=1132.67 (=> setval=70)*/
    {UMC_COMSIZE_32_32_L20_(0),	0x0c8b1341}, /*lsz=12, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1046.13 (=> setval=65)*/
    {UMC_COMSIZE_32_32_L21_(0),	0x108b1348}, /*lsz=16, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1156.9 (=> setval=72)*/
    {UMC_COMSIZE_32_32_L22_(0),	0x17841545}, /*lsz=23, cls=04, pin=0, ett=5, dir=r, CH=1, oh=1106.13 (=> setval=69)*/
    {UMC_COMSIZE_32_32_L23_(0),	0x17861448}, /*lsz=23, cls=06, pin=0, ett=4, dir=r, CH=1, oh=1158.27 (=> setval=72)*/
    {UMC_COMSIZE_32_32_L24_(0),	0x178b1351}, /*lsz=23, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1311.87 (=> setval=81)*/
    {UMC_COMSIZE_32_32_L25_(0),	0x10081b3e}, /*lsz=16, cls=08, pin=0, ett=11, dir=w, CH=1, oh=1002.0 (=> setval=62)*/
    {UMC_COMSIZE_32_32_L26_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L27_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L28_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L29_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L30_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L31_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L32_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L1_(0),	0x10081066}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1642.38 (=> setval=102)*/
    {UMC_COMSIZE_32_40_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L1_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L1_(0),	0x1008106e}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1770.5 (=> setval=110)*/
    {UMC_COMSIZE_40_40_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L1_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L2_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L3_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L4_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L1_(0),	0x02001004}, /*lsz=02, cls=00, pin=0, ett=0, dir=w, CH=1, oh=64  (=> setval=4)*/
    {UMC_COMSIZE_1D_L2_(0),	0x04001008}, /*lsz=04, cls=00, pin=0, ett=0, dir=w, CH=1, oh=128 (=> setval=8)*/
    {UMC_COMSIZE_1D_L3_(0),	0x08001010}, /*lsz=08, cls=00, pin=0, ett=0, dir=w, CH=1, oh=256 (=> setval=16)*/
    {UMC_COMSIZE_1D_L4_(0),	0x0c001018}, /*lsz=12, cls=00, pin=0, ett=0, dir=w, CH=1, oh=384 (=> setval=24)*/
    {UMC_COMSIZE_1D_L5_(0),	0x10001020}, /*lsz=16, cls=00, pin=0, ett=0, dir=w, CH=1, oh=512 (=> setval=32)*/
    {UMC_COMSIZE_1D_L6_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L7_(0),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L8_(0),	0x00000020}, /*NOT USE*/

  /*** For DDR3-CH1 ***/
    {UMC_COMSIZE_16_00_L1_(1),	0x04801116}, /*lsz=04, cls=00, pin=0, ett=1, dir=r, CH=1, oh=360.86 (=> setval=22)*/
    {UMC_COMSIZE_16_00_L2_(1),	0x08801117}, /*lsz=08, cls=00, pin=0, ett=1, dir=r, CH=1, oh=378.12 (=> setval=23)*/
    {UMC_COMSIZE_16_00_L3_(1),	0x0b801418}, /*lsz=11, cls=00, pin=0, ett=4, dir=r, CH=1, oh=398.73 (=> setval=24)*/
    {UMC_COMSIZE_16_00_L4_(1),	0x0c801519}, /*lsz=12, cls=00, pin=0, ett=5, dir=r, CH=1, oh=415.52 (=> setval=25)*/
    {UMC_COMSIZE_16_00_L5_(1),	0x0f80151d}, /*lsz=15, cls=00, pin=0, ett=5, dir=r, CH=1, oh=474.22 (=> setval=29)*/
    {UMC_COMSIZE_16_00_L6_(1),	0x1080151e}, /*lsz=16, cls=00, pin=0, ett=5, dir=r, CH=1, oh=490.12 (=> setval=30)*/
    {UMC_COMSIZE_16_00_L7_(1),	0x10001d21}, /*lsz=16, cls=00, pin=0, ett=13, dir=w, CH=1, oh=528.0 (=> setval=33)*/
    {UMC_COMSIZE_16_00_L8_(1),	0x13801621}, /*lsz=19, cls=00, pin=0, ett=6, dir=r, CH=1, oh=537.71 (=> setval=33)*/
    {UMC_COMSIZE_16_00_L9_(1),	0x17801525}, /*lsz=23, cls=00, pin=0, ett=5, dir=r, CH=1, oh=600.8 (=> setval=37)*/
    {UMC_COMSIZE_16_00_L10_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_00_L11_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_00_L12_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L1_(1),	0x84821117}, /*lsz=04, cls=02, pin=1, ett=1, dir=r, CH=1, oh=379.88 (=> setval=23)*/
    {UMC_COMSIZE_16_16_L2_(1),	0x8884171a}, /*lsz=08, cls=04, pin=1, ett=7, dir=r, CH=1, oh=419.84 (=> setval=26)*/
    {UMC_COMSIZE_16_16_L3_(1),	0x8b851a1d}, /*lsz=11, cls=05, pin=1, ett=10, dir=r, CH=1, oh=466.45 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L4_(1),	0x8c861b1e}, /*lsz=12, cls=06, pin=1, ett=11, dir=r, CH=1, oh=490.67 (=> setval=30)*/
    {UMC_COMSIZE_16_16_L5_(1),	0x8f871c22}, /*lsz=15, cls=07, pin=1, ett=12, dir=r, CH=1, oh=548.11 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L6_(1),	0x90881d23}, /*lsz=16, cls=08, pin=1, ett=13, dir=r, CH=1, oh=575.35 (=> setval=35)*/
    {UMC_COMSIZE_16_16_L7_(1),	0x93891e27}, /*lsz=19, cls=09, pin=1, ett=14, dir=r, CH=1, oh=633.0 (=> setval=39)*/
    {UMC_COMSIZE_16_16_L8_(1),	0x978b1d2c}, /*lsz=23, cls=11, pin=1, ett=13, dir=r, CH=1, oh=711.8 (=> setval=44)*/
    {UMC_COMSIZE_16_16_L9_(1),	0x04851318}, /*lsz=04, cls=05, pin=0, ett=3, dir=r, CH=1, oh=397.43 (=> setval=24)*/
    {UMC_COMSIZE_16_16_L10_(1),	0x0b851a1d}, /*lsz=11, cls=05, pin=0, ett=10, dir=r, CH=1, oh=466.45 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L11_(1),	0x04871519}, /*lsz=04, cls=07, pin=0, ett=5, dir=r, CH=1, oh=413.69 (=> setval=25)*/
    {UMC_COMSIZE_16_16_L12_(1),	0x0887191c}, /*lsz=08, cls=07, pin=0, ett=9, dir=r, CH=1, oh=448.58 (=> setval=28)*/
    {UMC_COMSIZE_16_16_L13_(1),	0x0f821820}, /*lsz=15, cls=02, pin=0, ett=8, dir=r, CH=1, oh=512.22 (=> setval=32)*/
    {UMC_COMSIZE_16_16_L14_(1),	0x0f871c22}, /*lsz=15, cls=07, pin=0, ett=12, dir=r, CH=1, oh=548.11 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L15_(1),	0x08891b1d}, /*lsz=08, cls=09, pin=0, ett=11, dir=r, CH=1, oh=469.38 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L16_(1),	0x0c891d20}, /*lsz=12, cls=09, pin=0, ett=13, dir=r, CH=1, oh=524.57 (=> setval=32)*/
    {UMC_COMSIZE_16_16_L17_(1),	0x13821923}, /*lsz=19, cls=02, pin=0, ett=9, dir=r, CH=1, oh=575.71 (=> setval=35)*/
    {UMC_COMSIZE_16_16_L18_(1),	0x13841c24}, /*lsz=19, cls=04, pin=0, ett=12, dir=r, CH=1, oh=588.57 (=> setval=36)*/
    {UMC_COMSIZE_16_16_L19_(1),	0x13891e27}, /*lsz=19, cls=09, pin=0, ett=14, dir=r, CH=1, oh=633.0 (=> setval=39)*/
    {UMC_COMSIZE_16_16_L20_(1),	0x0c8b1d22}, /*lsz=12, cls=11, pin=0, ett=13, dir=r, CH=1, oh=545.86 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L21_(1),	0x108b1d26}, /*lsz=16, cls=11, pin=0, ett=13, dir=r, CH=1, oh=608.29 (=> setval=38)*/
    {UMC_COMSIZE_16_16_L22_(1),	0x17841b28}, /*lsz=23, cls=04, pin=0, ett=11, dir=r, CH=1, oh=649.6 (=> setval=40)*/
    {UMC_COMSIZE_16_16_L23_(1),	0x17861c29}, /*lsz=23, cls=06, pin=0, ett=12, dir=r, CH=1, oh=665.8 (=> setval=41)*/
    {UMC_COMSIZE_16_16_L24_(1),	0x178b1d2c}, /*lsz=23, cls=11, pin=0, ett=13, dir=r, CH=1, oh=711.8 (=> setval=44)*/
    {UMC_COMSIZE_16_16_L25_(1),	0x10081030}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1026.0 (=> setval=64) for mdd*/
    {UMC_COMSIZE_16_16_L26_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L27_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L28_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L29_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L30_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L31_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L32_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L1_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L1_(1),	0x8482111b}, /*lsz=04, cls=02, pin=1, ett=1, dir=r, CH=1, oh=438.6 (=> setval=27)*/
    {UMC_COMSIZE_16_32_L2_(1),	0x8884161f}, /*lsz=08, cls=04, pin=1, ett=6, dir=r, CH=1, oh=509.6 (=> setval=31)*/
    {UMC_COMSIZE_16_32_L3_(1),	0x8b851823}, /*lsz=11, cls=05, pin=1, ett=8, dir=r, CH=1, oh=569.11 (=> setval=35)*/
    {UMC_COMSIZE_16_32_L4_(1),	0x8c861826}, /*lsz=12, cls=06, pin=1, ett=8, dir=r, CH=1, oh=620.94 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L5_(1),	0x8f87182b}, /*lsz=15, cls=07, pin=1, ett=8, dir=r, CH=1, oh=702.82 (=> setval=43)*/
    {UMC_COMSIZE_16_32_L6_(1),	0x9088182e}, /*lsz=16, cls=08, pin=1, ett=8, dir=r, CH=1, oh=745.43 (=> setval=46)*/
    {UMC_COMSIZE_16_32_L7_(1),	0x93891a33}, /*lsz=19, cls=09, pin=1, ett=10, dir=r, CH=1, oh=820.9 (=> setval=51)*/
    {UMC_COMSIZE_16_32_L8_(1),	0x978b173b}, /*lsz=23, cls=11, pin=1, ett=7, dir=r, CH=1, oh=953.29 (=> setval=59)*/
    {UMC_COMSIZE_16_32_L9_(1),	0x04851121}, /*lsz=04, cls=05, pin=0, ett=1, dir=r, CH=1, oh=529.33 (=> setval=33)*/
    {UMC_COMSIZE_16_32_L10_(1),	0x0b851823}, /*lsz=11, cls=05, pin=0, ett=8, dir=r, CH=1, oh=569.11 (=> setval=35)*/
    {UMC_COMSIZE_16_32_L11_(1),	0x04871125}, /*lsz=04, cls=07, pin=0, ett=1, dir=r, CH=1, oh=598.76 (=> setval=37)*/
    {UMC_COMSIZE_16_32_L12_(1),	0x08871426}, /*lsz=08, cls=07, pin=0, ett=4, dir=r, CH=1, oh=620.36 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L13_(1),	0x0f821922}, /*lsz=15, cls=02, pin=0, ett=9, dir=r, CH=1, oh=553.39 (=> setval=34)*/
    {UMC_COMSIZE_16_32_L14_(1),	0x0f87182b}, /*lsz=15, cls=07, pin=0, ett=8, dir=r, CH=1, oh=702.82 (=> setval=43)*/
    {UMC_COMSIZE_16_32_L15_(1),	0x0889132c}, /*lsz=08, cls=09, pin=0, ett=3, dir=r, CH=1, oh=707.64 (=> setval=44)*/
    {UMC_COMSIZE_16_32_L16_(1),	0x0c89152e}, /*lsz=12, cls=09, pin=0, ett=5, dir=r, CH=1, oh=751.0 (=> setval=46)*/
    {UMC_COMSIZE_16_32_L17_(1),	0x13821b26}, /*lsz=19, cls=02, pin=0, ett=11, dir=r, CH=1, oh=613.71 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L18_(1),	0x13841e29}, /*lsz=19, cls=04, pin=0, ett=14, dir=r, CH=1, oh=660.86 (=> setval=41)*/
    {UMC_COMSIZE_16_32_L19_(1),	0x13891a33}, /*lsz=19, cls=09, pin=0, ett=10, dir=r, CH=1, oh=820.9 (=> setval=51)*/
    {UMC_COMSIZE_16_32_L20_(1),	0x0c8b1334}, /*lsz=12, cls=11, pin=0, ett=3, dir=r, CH=1, oh=837.62 (=> setval=52)*/
    {UMC_COMSIZE_16_32_L21_(1),	0x108b1537}, /*lsz=16, cls=11, pin=0, ett=5, dir=r, CH=1, oh=883.53 (=> setval=55)*/
    {UMC_COMSIZE_16_32_L22_(1),	0x17841e2c}, /*lsz=23, cls=04, pin=0, ett=14, dir=r, CH=1, oh=717.6 (=> setval=44)*/
    {UMC_COMSIZE_16_32_L23_(1),	0x17861c30}, /*lsz=23, cls=06, pin=0, ett=12, dir=r, CH=1, oh=769.51 (=> setval=48)*/
    {UMC_COMSIZE_16_32_L24_(1),	0x178b173b}, /*lsz=23, cls=11, pin=0, ett=7, dir=r, CH=1, oh=953.29 (=> setval=59)*/
    {UMC_COMSIZE_16_32_L25_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L26_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L27_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L28_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L29_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L30_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L31_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L32_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L1_(1),	0x10081c37}, /*lsz=16, cls=08, pin=0, ett=12, dir=w, CH=1, oh=883.0 (=> setval=55)*/
    {UMC_COMSIZE_24_16_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L1_(1),	0x10081156}, /*lsz=16, cls=08, pin=0, ett=1, dir=w, CH=1, oh=1386.25 (=> setval=86)*/
    {UMC_COMSIZE_24_24_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L1_(1),	0x10081a3e}, /*lsz=16, cls=08, pin=0, ett=10, dir=w, CH=1, oh=1003.0 (=> setval=62)*/
    {UMC_COMSIZE_24_32_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L1_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_00_L1_(1),	0x04801119}, /*lsz=04, cls=00, pin=0, ett=1, dir=r, CH=1, oh=401.13 (=> setval=25)*/
    {UMC_COMSIZE_32_00_L2_(1),	0x0880171e}, /*lsz=08, cls=00, pin=0, ett=7, dir=r, CH=1, oh=484.05 (=> setval=30)*/
    {UMC_COMSIZE_32_00_L3_(1),	0x0b801723}, /*lsz=11, cls=00, pin=0, ett=7, dir=r, CH=1, oh=570.3 (=> setval=35)*/
    {UMC_COMSIZE_32_00_L4_(1),	0x0c801825}, /*lsz=12, cls=00, pin=0, ett=8, dir=r, CH=1, oh=603.49 (=> setval=37)*/
    {UMC_COMSIZE_32_00_L5_(1),	0x0f80172c}, /*lsz=15, cls=00, pin=0, ett=7, dir=r, CH=1, oh=705.78 (=> setval=44)*/
    {UMC_COMSIZE_32_00_L6_(1),	0x1080172e}, /*lsz=16, cls=00, pin=0, ett=7, dir=r, CH=1, oh=737.57 (=> setval=46)*/
    {UMC_COMSIZE_32_00_L7_(1),	0x10001040}, /*lsz=16, cls=00, pin=0, ett=0, dir=w, CH=1, oh=1037.0 (=> setval=64)*/
    {UMC_COMSIZE_32_00_L8_(1),	0x13801734}, /*lsz=19, cls=00, pin=0, ett=7, dir=r, CH=1, oh=832.76 (=> setval=52)*/
    {UMC_COMSIZE_32_00_L9_(1),	0x1780153b}, /*lsz=23, cls=00, pin=0, ett=5, dir=r, CH=1, oh=958.93 (=> setval=59)*/
    {UMC_COMSIZE_32_00_L10_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_00_L11_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_00_L12_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L1_(1),	0x8482141a}, /*lsz=04, cls=02, pin=1, ett=4, dir=r, CH=1, oh=425.34 (=> setval=26)*/
    {UMC_COMSIZE_32_16_L2_(1),	0x88841722}, /*lsz=08, cls=04, pin=1, ett=7, dir=r, CH=1, oh=550.63 (=> setval=34)*/
    {UMC_COMSIZE_32_16_L3_(1),	0x8b851729}, /*lsz=11, cls=05, pin=1, ett=7, dir=r, CH=1, oh=656.45 (=> setval=41)*/
    {UMC_COMSIZE_32_16_L4_(1),	0x8c86182b}, /*lsz=12, cls=06, pin=1, ett=8, dir=r, CH=1, oh=699.68 (=> setval=43)*/
    {UMC_COMSIZE_32_16_L5_(1),	0x8f871732}, /*lsz=15, cls=07, pin=1, ett=7, dir=r, CH=1, oh=807.78 (=> setval=50)*/
    {UMC_COMSIZE_32_16_L6_(1),	0x90881835}, /*lsz=16, cls=08, pin=1, ett=8, dir=r, CH=1, oh=853.06 (=> setval=53)*/
    {UMC_COMSIZE_32_16_L7_(1),	0x9389183c}, /*lsz=19, cls=09, pin=1, ett=8, dir=r, CH=1, oh=961.05 (=> setval=60)*/
    {UMC_COMSIZE_32_16_L8_(1),	0x978b1645}, /*lsz=23, cls=11, pin=1, ett=6, dir=r, CH=1, oh=1106.53 (=> setval=69)*/
    {UMC_COMSIZE_32_16_L9_(1),	0x0485151c}, /*lsz=04, cls=05, pin=0, ett=5, dir=r, CH=1, oh=453.83 (=> setval=28)*/
    {UMC_COMSIZE_32_16_L10_(1),	0x0b851729}, /*lsz=11, cls=05, pin=0, ett=7, dir=r, CH=1, oh=656.45 (=> setval=41)*/
    {UMC_COMSIZE_32_16_L11_(1),	0x0487161d}, /*lsz=04, cls=07, pin=0, ett=6, dir=r, CH=1, oh=472.57 (=> setval=29)*/
    {UMC_COMSIZE_32_16_L12_(1),	0x08871924}, /*lsz=08, cls=07, pin=0, ett=9, dir=r, CH=1, oh=584.93 (=> setval=36)*/
    {UMC_COMSIZE_32_16_L13_(1),	0x0f82162f}, /*lsz=15, cls=02, pin=0, ett=6, dir=r, CH=1, oh=757.78 (=> setval=47)*/
    {UMC_COMSIZE_32_16_L14_(1),	0x0f871732}, /*lsz=15, cls=07, pin=0, ett=7, dir=r, CH=1, oh=807.78 (=> setval=50)*/
    {UMC_COMSIZE_32_16_L15_(1),	0x08891926}, /*lsz=08, cls=09, pin=0, ett=9, dir=r, CH=1, oh=610.41 (=> setval=38)*/
    {UMC_COMSIZE_32_16_L16_(1),	0x0c89192e}, /*lsz=12, cls=09, pin=0, ett=9, dir=r, CH=1, oh=738.95 (=> setval=46)*/
    {UMC_COMSIZE_32_16_L17_(1),	0x13821737}, /*lsz=19, cls=02, pin=0, ett=7, dir=r, CH=1, oh=884.76 (=> setval=55)*/
    {UMC_COMSIZE_32_16_L18_(1),	0x13841738}, /*lsz=19, cls=04, pin=0, ett=7, dir=r, CH=1, oh=905.52 (=> setval=56)*/
    {UMC_COMSIZE_32_16_L19_(1),	0x1389183c}, /*lsz=19, cls=09, pin=0, ett=8, dir=r, CH=1, oh=961.05 (=> setval=60)*/
    {UMC_COMSIZE_32_16_L20_(1),	0x0c8b192f}, /*lsz=12, cls=11, pin=0, ett=9, dir=r, CH=1, oh=763.4 (=> setval=47)*/
    {UMC_COMSIZE_32_16_L21_(1),	0x108b1937}, /*lsz=16, cls=11, pin=0, ett=9, dir=r, CH=1, oh=890.71 (=> setval=55)*/
    {UMC_COMSIZE_32_16_L22_(1),	0x17841540}, /*lsz=23, cls=04, pin=0, ett=5, dir=r, CH=1, oh=1028.8 (=> setval=64)*/
    {UMC_COMSIZE_32_16_L23_(1),	0x17861641}, /*lsz=23, cls=06, pin=0, ett=6, dir=r, CH=1, oh=1050.27 (=> setval=65)*/
    {UMC_COMSIZE_32_16_L24_(1),	0x178b1645}, /*lsz=23, cls=11, pin=0, ett=6, dir=r, CH=1, oh=1106.53 (=> setval=69)*/
    {UMC_COMSIZE_32_16_L25_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L26_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L27_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L28_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L29_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L30_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L31_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L32_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L1_(1),	0x1008105e}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1514.38 (=> setval=94)*/
    {UMC_COMSIZE_32_24_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L1_(1),	0x8482131d}, /*lsz=04, cls=02, pin=1, ett=3, dir=r, CH=1, oh=478.14 (=> setval=29)*/
    {UMC_COMSIZE_32_32_L2_(1),	0x88841627}, /*lsz=08, cls=04, pin=1, ett=6, dir=r, CH=1, oh=635.37 (=> setval=39)*/
    {UMC_COMSIZE_32_32_L3_(1),	0x8b85152e}, /*lsz=11, cls=05, pin=1, ett=5, dir=r, CH=1, oh=750.52 (=> setval=46)*/
    {UMC_COMSIZE_32_32_L4_(1),	0x8c861633}, /*lsz=12, cls=06, pin=1, ett=6, dir=r, CH=1, oh=816.17 (=> setval=51)*/
    {UMC_COMSIZE_32_32_L5_(1),	0x8f87153a}, /*lsz=15, cls=07, pin=1, ett=5, dir=r, CH=1, oh=933.56 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L6_(1),	0x9088153f}, /*lsz=16, cls=08, pin=1, ett=5, dir=r, CH=1, oh=1011.02 (=> setval=63)*/
    {UMC_COMSIZE_32_32_L7_(1),	0x93891546}, /*lsz=19, cls=09, pin=1, ett=5, dir=r, CH=1, oh=1132.67 (=> setval=70)*/
    {UMC_COMSIZE_32_32_L8_(1),	0x978b1351}, /*lsz=23, cls=11, pin=1, ett=3, dir=r, CH=1, oh=1311.87 (=> setval=81)*/
    {UMC_COMSIZE_32_32_L9_(1),	0x04851324}, /*lsz=04, cls=05, pin=0, ett=3, dir=r, CH=1, oh=587.21 (=> setval=36)*/
    {UMC_COMSIZE_32_32_L10_(1),	0x0b85152e}, /*lsz=11, cls=05, pin=0, ett=5, dir=r, CH=1, oh=750.52 (=> setval=46)*/
    {UMC_COMSIZE_32_32_L11_(1),	0x04871229}, /*lsz=04, cls=07, pin=0, ett=2, dir=r, CH=1, oh=664.35 (=> setval=41)*/
    {UMC_COMSIZE_32_32_L12_(1),	0x0887142f}, /*lsz=08, cls=07, pin=0, ett=4, dir=r, CH=1, oh=758.29 (=> setval=47)*/
    {UMC_COMSIZE_32_32_L13_(1),	0x0f821632}, /*lsz=15, cls=02, pin=0, ett=6, dir=r, CH=1, oh=804.44 (=> setval=50)*/
    {UMC_COMSIZE_32_32_L14_(1),	0x0f87153a}, /*lsz=15, cls=07, pin=0, ett=5, dir=r, CH=1, oh=933.56 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L15_(1),	0x08891334}, /*lsz=08, cls=09, pin=0, ett=3, dir=r, CH=1, oh=846.77 (=> setval=52)*/
    {UMC_COMSIZE_32_32_L16_(1),	0x0c89143c}, /*lsz=12, cls=09, pin=0, ett=4, dir=r, CH=1, oh=961.38 (=> setval=60)*/
    {UMC_COMSIZE_32_32_L17_(1),	0x1382163a}, /*lsz=19, cls=02, pin=0, ett=6, dir=r, CH=1, oh=931.43 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L18_(1),	0x1384163d}, /*lsz=19, cls=04, pin=0, ett=6, dir=r, CH=1, oh=987.24 (=> setval=61)*/
    {UMC_COMSIZE_32_32_L19_(1),	0x13891546}, /*lsz=19, cls=09, pin=0, ett=5, dir=r, CH=1, oh=1132.67 (=> setval=70)*/
    {UMC_COMSIZE_32_32_L20_(1),	0x0c8b1341}, /*lsz=12, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1046.13 (=> setval=65)*/
    {UMC_COMSIZE_32_32_L21_(1),	0x108b1348}, /*lsz=16, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1156.9 (=> setval=72)*/
    {UMC_COMSIZE_32_32_L22_(1),	0x17841545}, /*lsz=23, cls=04, pin=0, ett=5, dir=r, CH=1, oh=1106.13 (=> setval=69)*/
    {UMC_COMSIZE_32_32_L23_(1),	0x17861448}, /*lsz=23, cls=06, pin=0, ett=4, dir=r, CH=1, oh=1158.27 (=> setval=72)*/
    {UMC_COMSIZE_32_32_L24_(1),	0x178b1351}, /*lsz=23, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1311.87 (=> setval=81)*/
    {UMC_COMSIZE_32_32_L25_(1),	0x10081b3e}, /*lsz=16, cls=08, pin=0, ett=11, dir=w, CH=1, oh=1002.0 (=> setval=62)*/
    {UMC_COMSIZE_32_32_L26_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L27_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L28_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L29_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L30_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L31_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L32_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L1_(1),	0x10081066}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1642.38 (=> setval=102)*/
    {UMC_COMSIZE_32_40_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L1_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L1_(1),	0x1008106e}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1770.5 (=> setval=110)*/
    {UMC_COMSIZE_40_40_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L1_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L2_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L3_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L4_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L1_(1),     0x02001004}, /*lsz=02, cls=00, pin=0, ett=0, dir=w, CH=1, oh=64  (=> setval=4)*/
    {UMC_COMSIZE_1D_L2_(1),     0x04001008}, /*lsz=04, cls=00, pin=0, ett=0, dir=w, CH=1, oh=128 (=> setval=8)*/
    {UMC_COMSIZE_1D_L3_(1),     0x08001010}, /*lsz=08, cls=00, pin=0, ett=0, dir=w, CH=1, oh=256 (=> setval=16)*/
    {UMC_COMSIZE_1D_L4_(1),     0x0c001018}, /*lsz=12, cls=00, pin=0, ett=0, dir=w, CH=1, oh=384 (=> setval=24)*/
    {UMC_COMSIZE_1D_L5_(1),     0x10001020}, /*lsz=16, cls=00, pin=0, ett=0, dir=w, CH=1, oh=512 (=> setval=32)*/
    {UMC_COMSIZE_1D_L6_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L7_(1),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L8_(1),	0x00000020}, /*NOT USE*/

  /*** For DDR3-CH2 ***/
    {UMC_COMSIZE_16_00_L1_(2),	0x04801116}, /*lsz=04, cls=00, pin=0, ett=1, dir=r, CH=1, oh=360.86 (=> setval=22)*/
    {UMC_COMSIZE_16_00_L2_(2),	0x08801117}, /*lsz=08, cls=00, pin=0, ett=1, dir=r, CH=1, oh=378.12 (=> setval=23)*/
    {UMC_COMSIZE_16_00_L3_(2),	0x0b801418}, /*lsz=11, cls=00, pin=0, ett=4, dir=r, CH=1, oh=398.73 (=> setval=24)*/
    {UMC_COMSIZE_16_00_L4_(2),	0x0c801519}, /*lsz=12, cls=00, pin=0, ett=5, dir=r, CH=1, oh=415.52 (=> setval=25)*/
    {UMC_COMSIZE_16_00_L5_(2),	0x0f80151d}, /*lsz=15, cls=00, pin=0, ett=5, dir=r, CH=1, oh=474.22 (=> setval=29)*/
    {UMC_COMSIZE_16_00_L6_(2),	0x1080151e}, /*lsz=16, cls=00, pin=0, ett=5, dir=r, CH=1, oh=490.12 (=> setval=30)*/
    {UMC_COMSIZE_16_00_L7_(2),	0x10001d21}, /*lsz=16, cls=00, pin=0, ett=13, dir=w, CH=1, oh=528.0 (=> setval=33)*/
    {UMC_COMSIZE_16_00_L8_(2),	0x13801621}, /*lsz=19, cls=00, pin=0, ett=6, dir=r, CH=1, oh=537.71 (=> setval=33)*/
    {UMC_COMSIZE_16_00_L9_(2),	0x17801525}, /*lsz=23, cls=00, pin=0, ett=5, dir=r, CH=1, oh=600.8 (=> setval=37)*/
    {UMC_COMSIZE_16_00_L10_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_00_L11_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_00_L12_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L1_(2),	0x84821117}, /*lsz=04, cls=02, pin=1, ett=1, dir=r, CH=1, oh=379.88 (=> setval=23)*/
    {UMC_COMSIZE_16_16_L2_(2),	0x8884171a}, /*lsz=08, cls=04, pin=1, ett=7, dir=r, CH=1, oh=419.84 (=> setval=26)*/
    {UMC_COMSIZE_16_16_L3_(2),	0x8b851a1d}, /*lsz=11, cls=05, pin=1, ett=10, dir=r, CH=1, oh=466.45 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L4_(2),	0x8c861b1e}, /*lsz=12, cls=06, pin=1, ett=11, dir=r, CH=1, oh=490.67 (=> setval=30)*/
    {UMC_COMSIZE_16_16_L5_(2),	0x8f871c22}, /*lsz=15, cls=07, pin=1, ett=12, dir=r, CH=1, oh=548.11 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L6_(2),	0x90881d23}, /*lsz=16, cls=08, pin=1, ett=13, dir=r, CH=1, oh=575.35 (=> setval=35)*/
    {UMC_COMSIZE_16_16_L7_(2),	0x93891e27}, /*lsz=19, cls=09, pin=1, ett=14, dir=r, CH=1, oh=633.0 (=> setval=39)*/
    {UMC_COMSIZE_16_16_L8_(2),	0x978b1d2c}, /*lsz=23, cls=11, pin=1, ett=13, dir=r, CH=1, oh=711.8 (=> setval=44)*/
    {UMC_COMSIZE_16_16_L9_(2),	0x04851318}, /*lsz=04, cls=05, pin=0, ett=3, dir=r, CH=1, oh=397.43 (=> setval=24)*/
    {UMC_COMSIZE_16_16_L10_(2),	0x0b851a1d}, /*lsz=11, cls=05, pin=0, ett=10, dir=r, CH=1, oh=466.45 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L11_(2),	0x04871519}, /*lsz=04, cls=07, pin=0, ett=5, dir=r, CH=1, oh=413.69 (=> setval=25)*/
    {UMC_COMSIZE_16_16_L12_(2),	0x0887191c}, /*lsz=08, cls=07, pin=0, ett=9, dir=r, CH=1, oh=448.58 (=> setval=28)*/
    {UMC_COMSIZE_16_16_L13_(2),	0x0f821820}, /*lsz=15, cls=02, pin=0, ett=8, dir=r, CH=1, oh=512.22 (=> setval=32)*/
    {UMC_COMSIZE_16_16_L14_(2),	0x0f871c22}, /*lsz=15, cls=07, pin=0, ett=12, dir=r, CH=1, oh=548.11 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L15_(2),	0x08891b1d}, /*lsz=08, cls=09, pin=0, ett=11, dir=r, CH=1, oh=469.38 (=> setval=29)*/
    {UMC_COMSIZE_16_16_L16_(2),	0x0c891d20}, /*lsz=12, cls=09, pin=0, ett=13, dir=r, CH=1, oh=524.57 (=> setval=32)*/
    {UMC_COMSIZE_16_16_L17_(2),	0x13821923}, /*lsz=19, cls=02, pin=0, ett=9, dir=r, CH=1, oh=575.71 (=> setval=35)*/
    {UMC_COMSIZE_16_16_L18_(2),	0x13841c24}, /*lsz=19, cls=04, pin=0, ett=12, dir=r, CH=1, oh=588.57 (=> setval=36)*/
    {UMC_COMSIZE_16_16_L19_(2),	0x13891e27}, /*lsz=19, cls=09, pin=0, ett=14, dir=r, CH=1, oh=633.0 (=> setval=39)*/
    {UMC_COMSIZE_16_16_L20_(2),	0x0c8b1d22}, /*lsz=12, cls=11, pin=0, ett=13, dir=r, CH=1, oh=545.86 (=> setval=34)*/
    {UMC_COMSIZE_16_16_L21_(2),	0x108b1d26}, /*lsz=16, cls=11, pin=0, ett=13, dir=r, CH=1, oh=608.29 (=> setval=38)*/
    {UMC_COMSIZE_16_16_L22_(2),	0x17841b28}, /*lsz=23, cls=04, pin=0, ett=11, dir=r, CH=1, oh=649.6 (=> setval=40)*/
    {UMC_COMSIZE_16_16_L23_(2),	0x17861c29}, /*lsz=23, cls=06, pin=0, ett=12, dir=r, CH=1, oh=665.8 (=> setval=41)*/
    {UMC_COMSIZE_16_16_L24_(2),	0x178b1d2c}, /*lsz=23, cls=11, pin=0, ett=13, dir=r, CH=1, oh=711.8 (=> setval=44)*/
    {UMC_COMSIZE_16_16_L25_(2),	0x10081040}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1026.0 (=> setval=64)*/
    {UMC_COMSIZE_16_16_L26_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L27_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L28_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L29_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L30_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L31_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_16_L32_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L1_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_24_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L1_(2),	0x8482111b}, /*lsz=04, cls=02, pin=1, ett=1, dir=r, CH=1, oh=438.6 (=> setval=27)*/
    {UMC_COMSIZE_16_32_L2_(2),	0x8884161f}, /*lsz=08, cls=04, pin=1, ett=6, dir=r, CH=1, oh=509.6 (=> setval=31)*/
    {UMC_COMSIZE_16_32_L3_(2),	0x8b851823}, /*lsz=11, cls=05, pin=1, ett=8, dir=r, CH=1, oh=569.11 (=> setval=35)*/
    {UMC_COMSIZE_16_32_L4_(2),	0x8c861826}, /*lsz=12, cls=06, pin=1, ett=8, dir=r, CH=1, oh=620.94 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L5_(2),	0x8f87182b}, /*lsz=15, cls=07, pin=1, ett=8, dir=r, CH=1, oh=702.82 (=> setval=43)*/
    {UMC_COMSIZE_16_32_L6_(2),	0x9088182e}, /*lsz=16, cls=08, pin=1, ett=8, dir=r, CH=1, oh=745.43 (=> setval=46)*/
    {UMC_COMSIZE_16_32_L7_(2),	0x93891a33}, /*lsz=19, cls=09, pin=1, ett=10, dir=r, CH=1, oh=820.9 (=> setval=51)*/
    {UMC_COMSIZE_16_32_L8_(2),	0x978b173b}, /*lsz=23, cls=11, pin=1, ett=7, dir=r, CH=1, oh=953.29 (=> setval=59)*/
    {UMC_COMSIZE_16_32_L9_(2),	0x04851121}, /*lsz=04, cls=05, pin=0, ett=1, dir=r, CH=1, oh=529.33 (=> setval=33)*/
    {UMC_COMSIZE_16_32_L10_(2),	0x0b851823}, /*lsz=11, cls=05, pin=0, ett=8, dir=r, CH=1, oh=569.11 (=> setval=35)*/
    {UMC_COMSIZE_16_32_L11_(2),	0x04871125}, /*lsz=04, cls=07, pin=0, ett=1, dir=r, CH=1, oh=598.76 (=> setval=37)*/
    {UMC_COMSIZE_16_32_L12_(2),	0x08871426}, /*lsz=08, cls=07, pin=0, ett=4, dir=r, CH=1, oh=620.36 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L13_(2),	0x0f821922}, /*lsz=15, cls=02, pin=0, ett=9, dir=r, CH=1, oh=553.39 (=> setval=34)*/
    {UMC_COMSIZE_16_32_L14_(2),	0x0f87182b}, /*lsz=15, cls=07, pin=0, ett=8, dir=r, CH=1, oh=702.82 (=> setval=43)*/
    {UMC_COMSIZE_16_32_L15_(2),	0x0889132c}, /*lsz=08, cls=09, pin=0, ett=3, dir=r, CH=1, oh=707.64 (=> setval=44)*/
    {UMC_COMSIZE_16_32_L16_(2),	0x0c89152e}, /*lsz=12, cls=09, pin=0, ett=5, dir=r, CH=1, oh=751.0 (=> setval=46)*/
    {UMC_COMSIZE_16_32_L17_(2),	0x13821b26}, /*lsz=19, cls=02, pin=0, ett=11, dir=r, CH=1, oh=613.71 (=> setval=38)*/
    {UMC_COMSIZE_16_32_L18_(2),	0x13841e29}, /*lsz=19, cls=04, pin=0, ett=14, dir=r, CH=1, oh=660.86 (=> setval=41)*/
    {UMC_COMSIZE_16_32_L19_(2),	0x13891a33}, /*lsz=19, cls=09, pin=0, ett=10, dir=r, CH=1, oh=820.9 (=> setval=51)*/
    {UMC_COMSIZE_16_32_L20_(2),	0x0c8b1334}, /*lsz=12, cls=11, pin=0, ett=3, dir=r, CH=1, oh=837.62 (=> setval=52)*/
    {UMC_COMSIZE_16_32_L21_(2),	0x108b1537}, /*lsz=16, cls=11, pin=0, ett=5, dir=r, CH=1, oh=883.53 (=> setval=55)*/
    {UMC_COMSIZE_16_32_L22_(2),	0x17841e2c}, /*lsz=23, cls=04, pin=0, ett=14, dir=r, CH=1, oh=717.6 (=> setval=44)*/
    {UMC_COMSIZE_16_32_L23_(2),	0x17861c30}, /*lsz=23, cls=06, pin=0, ett=12, dir=r, CH=1, oh=769.51 (=> setval=48)*/
    {UMC_COMSIZE_16_32_L24_(2),	0x178b173b}, /*lsz=23, cls=11, pin=0, ett=7, dir=r, CH=1, oh=953.29 (=> setval=59)*/
    {UMC_COMSIZE_16_32_L25_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L26_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L27_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L28_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L29_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L30_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L31_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_16_32_L32_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L1_(2),	0x10081c37}, /*lsz=16, cls=08, pin=0, ett=12, dir=w, CH=1, oh=883.0 (=> setval=55)*/
    {UMC_COMSIZE_24_16_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_16_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L1_(2),	0x10081156}, /*lsz=16, cls=08, pin=0, ett=1, dir=w, CH=1, oh=1386.25 (=> setval=86)*/
    {UMC_COMSIZE_24_24_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_24_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L1_(2),	0x10081a3e}, /*lsz=16, cls=08, pin=0, ett=10, dir=w, CH=1, oh=1003.0 (=> setval=62)*/
    {UMC_COMSIZE_24_32_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_32_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L1_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_24_40_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_00_L1_(2),	0x04801119}, /*lsz=04, cls=00, pin=0, ett=1, dir=r, CH=1, oh=401.13 (=> setval=25)*/
    {UMC_COMSIZE_32_00_L2_(2),	0x0880171e}, /*lsz=08, cls=00, pin=0, ett=7, dir=r, CH=1, oh=484.05 (=> setval=30)*/
    {UMC_COMSIZE_32_00_L3_(2),	0x0b801723}, /*lsz=11, cls=00, pin=0, ett=7, dir=r, CH=1, oh=570.3 (=> setval=35)*/
    {UMC_COMSIZE_32_00_L4_(2),	0x0c801825}, /*lsz=12, cls=00, pin=0, ett=8, dir=r, CH=1, oh=603.49 (=> setval=37)*/
    {UMC_COMSIZE_32_00_L5_(2),	0x0f80172c}, /*lsz=15, cls=00, pin=0, ett=7, dir=r, CH=1, oh=705.78 (=> setval=44)*/
    {UMC_COMSIZE_32_00_L6_(2),	0x1080172e}, /*lsz=16, cls=00, pin=0, ett=7, dir=r, CH=1, oh=737.57 (=> setval=46)*/
    {UMC_COMSIZE_32_00_L7_(2),	0x10001040}, /*lsz=16, cls=00, pin=0, ett=0, dir=w, CH=1, oh=1037.0 (=> setval=64)*/
    {UMC_COMSIZE_32_00_L8_(2),	0x13801734}, /*lsz=19, cls=00, pin=0, ett=7, dir=r, CH=1, oh=832.76 (=> setval=52)*/
    {UMC_COMSIZE_32_00_L9_(2),	0x1780153b}, /*lsz=23, cls=00, pin=0, ett=5, dir=r, CH=1, oh=958.93 (=> setval=59)*/
    {UMC_COMSIZE_32_00_L10_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_00_L11_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_00_L12_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L1_(2),	0x8482141a}, /*lsz=04, cls=02, pin=1, ett=4, dir=r, CH=1, oh=425.34 (=> setval=26)*/
    {UMC_COMSIZE_32_16_L2_(2),	0x88841722}, /*lsz=08, cls=04, pin=1, ett=7, dir=r, CH=1, oh=550.63 (=> setval=34)*/
    {UMC_COMSIZE_32_16_L3_(2),	0x8b851729}, /*lsz=11, cls=05, pin=1, ett=7, dir=r, CH=1, oh=656.45 (=> setval=41)*/
    {UMC_COMSIZE_32_16_L4_(2),	0x8c86182b}, /*lsz=12, cls=06, pin=1, ett=8, dir=r, CH=1, oh=699.68 (=> setval=43)*/
    {UMC_COMSIZE_32_16_L5_(2),	0x8f871732}, /*lsz=15, cls=07, pin=1, ett=7, dir=r, CH=1, oh=807.78 (=> setval=50)*/
    {UMC_COMSIZE_32_16_L6_(2),	0x90881835}, /*lsz=16, cls=08, pin=1, ett=8, dir=r, CH=1, oh=853.06 (=> setval=53)*/
    {UMC_COMSIZE_32_16_L7_(2),	0x9389183c}, /*lsz=19, cls=09, pin=1, ett=8, dir=r, CH=1, oh=961.05 (=> setval=60)*/
    {UMC_COMSIZE_32_16_L8_(2),	0x978b1645}, /*lsz=23, cls=11, pin=1, ett=6, dir=r, CH=1, oh=1106.53 (=> setval=69)*/
    {UMC_COMSIZE_32_16_L9_(2),	0x0485151c}, /*lsz=04, cls=05, pin=0, ett=5, dir=r, CH=1, oh=453.83 (=> setval=28)*/
    {UMC_COMSIZE_32_16_L10_(2),	0x0b851729}, /*lsz=11, cls=05, pin=0, ett=7, dir=r, CH=1, oh=656.45 (=> setval=41)*/
    {UMC_COMSIZE_32_16_L11_(2),	0x0487161d}, /*lsz=04, cls=07, pin=0, ett=6, dir=r, CH=1, oh=472.57 (=> setval=29)*/
    {UMC_COMSIZE_32_16_L12_(2),	0x08871924}, /*lsz=08, cls=07, pin=0, ett=9, dir=r, CH=1, oh=584.93 (=> setval=36)*/
    {UMC_COMSIZE_32_16_L13_(2),	0x0f82162f}, /*lsz=15, cls=02, pin=0, ett=6, dir=r, CH=1, oh=757.78 (=> setval=47)*/
    {UMC_COMSIZE_32_16_L14_(2),	0x0f871732}, /*lsz=15, cls=07, pin=0, ett=7, dir=r, CH=1, oh=807.78 (=> setval=50)*/
    {UMC_COMSIZE_32_16_L15_(2),	0x08891926}, /*lsz=08, cls=09, pin=0, ett=9, dir=r, CH=1, oh=610.41 (=> setval=38)*/
    {UMC_COMSIZE_32_16_L16_(2),	0x0c89192e}, /*lsz=12, cls=09, pin=0, ett=9, dir=r, CH=1, oh=738.95 (=> setval=46)*/
    {UMC_COMSIZE_32_16_L17_(2),	0x13821737}, /*lsz=19, cls=02, pin=0, ett=7, dir=r, CH=1, oh=884.76 (=> setval=55)*/
    {UMC_COMSIZE_32_16_L18_(2),	0x13841738}, /*lsz=19, cls=04, pin=0, ett=7, dir=r, CH=1, oh=905.52 (=> setval=56)*/
    {UMC_COMSIZE_32_16_L19_(2),	0x1389183c}, /*lsz=19, cls=09, pin=0, ett=8, dir=r, CH=1, oh=961.05 (=> setval=60)*/
    {UMC_COMSIZE_32_16_L20_(2),	0x0c8b192f}, /*lsz=12, cls=11, pin=0, ett=9, dir=r, CH=1, oh=763.4 (=> setval=47)*/
    {UMC_COMSIZE_32_16_L21_(2),	0x108b1937}, /*lsz=16, cls=11, pin=0, ett=9, dir=r, CH=1, oh=890.71 (=> setval=55)*/
    {UMC_COMSIZE_32_16_L22_(2),	0x17841540}, /*lsz=23, cls=04, pin=0, ett=5, dir=r, CH=1, oh=1028.8 (=> setval=64)*/
    {UMC_COMSIZE_32_16_L23_(2),	0x17861641}, /*lsz=23, cls=06, pin=0, ett=6, dir=r, CH=1, oh=1050.27 (=> setval=65)*/
    {UMC_COMSIZE_32_16_L24_(2),	0x178b1645}, /*lsz=23, cls=11, pin=0, ett=6, dir=r, CH=1, oh=1106.53 (=> setval=69)*/
    {UMC_COMSIZE_32_16_L25_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L26_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L27_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L28_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L29_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L30_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L31_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_16_L32_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L1_(2),	0x1008105e}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1514.38 (=> setval=94)*/
    {UMC_COMSIZE_32_24_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_24_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L1_(2),	0x8482131d}, /*lsz=04, cls=02, pin=1, ett=3, dir=r, CH=1, oh=478.14 (=> setval=29)*/
    {UMC_COMSIZE_32_32_L2_(2),	0x88841627}, /*lsz=08, cls=04, pin=1, ett=6, dir=r, CH=1, oh=635.37 (=> setval=39)*/
    {UMC_COMSIZE_32_32_L3_(2),	0x8b85152e}, /*lsz=11, cls=05, pin=1, ett=5, dir=r, CH=1, oh=750.52 (=> setval=46)*/
    {UMC_COMSIZE_32_32_L4_(2),	0x8c861633}, /*lsz=12, cls=06, pin=1, ett=6, dir=r, CH=1, oh=816.17 (=> setval=51)*/
    {UMC_COMSIZE_32_32_L5_(2),	0x8f87153a}, /*lsz=15, cls=07, pin=1, ett=5, dir=r, CH=1, oh=933.56 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L6_(2),	0x9088153f}, /*lsz=16, cls=08, pin=1, ett=5, dir=r, CH=1, oh=1011.02 (=> setval=63)*/
    {UMC_COMSIZE_32_32_L7_(2),	0x93891546}, /*lsz=19, cls=09, pin=1, ett=5, dir=r, CH=1, oh=1132.67 (=> setval=70)*/
    {UMC_COMSIZE_32_32_L8_(2),	0x978b1351}, /*lsz=23, cls=11, pin=1, ett=3, dir=r, CH=1, oh=1311.87 (=> setval=81)*/
    {UMC_COMSIZE_32_32_L9_(2),	0x04851324}, /*lsz=04, cls=05, pin=0, ett=3, dir=r, CH=1, oh=587.21 (=> setval=36)*/
    {UMC_COMSIZE_32_32_L10_(2),	0x0b85152e}, /*lsz=11, cls=05, pin=0, ett=5, dir=r, CH=1, oh=750.52 (=> setval=46)*/
    {UMC_COMSIZE_32_32_L11_(2),	0x04871229}, /*lsz=04, cls=07, pin=0, ett=2, dir=r, CH=1, oh=664.35 (=> setval=41)*/
    {UMC_COMSIZE_32_32_L12_(2),	0x0887142f}, /*lsz=08, cls=07, pin=0, ett=4, dir=r, CH=1, oh=758.29 (=> setval=47)*/
    {UMC_COMSIZE_32_32_L13_(2),	0x0f821632}, /*lsz=15, cls=02, pin=0, ett=6, dir=r, CH=1, oh=804.44 (=> setval=50)*/
    {UMC_COMSIZE_32_32_L14_(2),	0x0f87153a}, /*lsz=15, cls=07, pin=0, ett=5, dir=r, CH=1, oh=933.56 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L15_(2),	0x08891334}, /*lsz=08, cls=09, pin=0, ett=3, dir=r, CH=1, oh=846.77 (=> setval=52)*/
    {UMC_COMSIZE_32_32_L16_(2),	0x0c89143c}, /*lsz=12, cls=09, pin=0, ett=4, dir=r, CH=1, oh=961.38 (=> setval=60)*/
    {UMC_COMSIZE_32_32_L17_(2),	0x1382163a}, /*lsz=19, cls=02, pin=0, ett=6, dir=r, CH=1, oh=931.43 (=> setval=58)*/
    {UMC_COMSIZE_32_32_L18_(2),	0x1384163d}, /*lsz=19, cls=04, pin=0, ett=6, dir=r, CH=1, oh=987.24 (=> setval=61)*/
    {UMC_COMSIZE_32_32_L19_(2),	0x13891546}, /*lsz=19, cls=09, pin=0, ett=5, dir=r, CH=1, oh=1132.67 (=> setval=70)*/
    {UMC_COMSIZE_32_32_L20_(2),	0x0c8b1341}, /*lsz=12, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1046.13 (=> setval=65)*/
    {UMC_COMSIZE_32_32_L21_(2),	0x108b1348}, /*lsz=16, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1156.9 (=> setval=72)*/
    {UMC_COMSIZE_32_32_L22_(2),	0x17841545}, /*lsz=23, cls=04, pin=0, ett=5, dir=r, CH=1, oh=1106.13 (=> setval=69)*/
    {UMC_COMSIZE_32_32_L23_(2),	0x17861448}, /*lsz=23, cls=06, pin=0, ett=4, dir=r, CH=1, oh=1158.27 (=> setval=72)*/
    {UMC_COMSIZE_32_32_L24_(2),	0x178b1351}, /*lsz=23, cls=11, pin=0, ett=3, dir=r, CH=1, oh=1311.87 (=> setval=81)*/
    {UMC_COMSIZE_32_32_L25_(2),	0x10081b3e}, /*lsz=16, cls=08, pin=0, ett=11, dir=w, CH=1, oh=1002.0 (=> setval=62)*/
    {UMC_COMSIZE_32_32_L26_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L27_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L28_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L29_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L30_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L31_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_32_L32_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L1_(2),	0x10081066}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1642.38 (=> setval=102)*/
    {UMC_COMSIZE_32_40_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_32_40_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L1_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_24_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L1_(2),	0x1008106e}, /*lsz=16, cls=08, pin=0, ett=0, dir=w, CH=1, oh=1770.5 (=> setval=110)*/
    {UMC_COMSIZE_40_40_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_40_40_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L1_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L2_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L3_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_48_00_L4_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L1_(2),     0x02001004}, /*lsz=02, cls=00, pin=0, ett=0, dir=w, CH=1, oh=64  (=> setval=4)*/
    {UMC_COMSIZE_1D_L2_(2),     0x04001008}, /*lsz=04, cls=00, pin=0, ett=0, dir=w, CH=1, oh=128 (=> setval=8)*/
    {UMC_COMSIZE_1D_L3_(2),     0x08001010}, /*lsz=08, cls=00, pin=0, ett=0, dir=w, CH=1, oh=256 (=> setval=16)*/
    {UMC_COMSIZE_1D_L4_(2),     0x0c001018}, /*lsz=12, cls=00, pin=0, ett=0, dir=w, CH=1, oh=384 (=> setval=24)*/
    {UMC_COMSIZE_1D_L5_(2),     0x10001020}, /*lsz=16, cls=00, pin=0, ett=0, dir=w, CH=1, oh=512 (=> setval=32)*/
    {UMC_COMSIZE_1D_L6_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L7_(2),	0x00000020}, /*NOT USE*/
    {UMC_COMSIZE_1D_L8_(2),	0x00000020}, /*NOT USE*/
    {UMC_FUNC_DATA_END, 0x0 }
};

const umc_addrdata_t UMC_FUNC_USECASE_PXS3_BDR20G_BASE[] = {
    { UMC_RATECONT_ICS(0),    0x01005100},
    { UMC_RATECONT_ICA(0),    0x06194319},
    { UMC_RATECONT_ICV(0),    0x01005100},
    { UMC_RATECONT_HDM(0),    0x04C841C8},
    { UMC_RATECONT_MDM(0),    0x01005100},
    { UMC_RATECONT_HDD(0),    0x03B040B0},
    { UMC_RATECONT_MDD(0),    0x01005100},
    { UMC_RATECONT_SIO(0),    0x03984098},
    { UMC_RATECONT_GIO(0),    0x04AA41AA},
    { UMC_RATECONT_VO1(0),    0x037A407A},
    { UMC_RATECONT_VO2(0),    0x01005100},
    { UMC_RATECONT_VO0(0),    0x01005100},
    { UMC_RATECONT_VDV(0),    0x01005100},
    { UMC_RATECONT_VPE(0),    0x03484048},
    { UMC_RATECONT_RG0(0),    0x01005100},
    { UMC_RATECONT_GR0(0),    0x01005100},
    { UMC_RATECONT_VG2(0),    0x01005100},
    { UMC_RATECONT_PCI(0),    0x01005100},
    { UMC_RATECONT_AIO(0),    0x0B094809},
    { UMC_RATECONT_VDM(0),    0x01005100},
    { UMC_RATECONT_REF(0),    0x0AAB47AB},
    { UMC_RATECONT_IDS(0),    0x0D994A99},
    { UMC_RATECONT_ID2(0),    0x0D994A99},
    { UMC_RATECONT_IXM(0),    0x03824082},
    { UMC_RATECONT_VDC(0),    0x01005100},
    { UMC_RATECONT_VDW(0),    0x03414041},
    { UMC_RATECONT_VW2(0),    0x03414041},
    { UMC_RATECONT_AR0(0),    0x01005100},
    { UMC_RATECONT_PXT(0),    0x047C417C},
    { UMC_RATECONT_PXW(0),    0x04544154},
    { UMC_RATECONT_PXR(0),    0x03B040B0},
    { UMC_RATECONT_ICS(1),    0x01005100},
    { UMC_RATECONT_ICA(1),    0x01005100},
    { UMC_RATECONT_ICV(1),    0x01005100},
    { UMC_RATECONT_HDM(1),    0x01005100},
    { UMC_RATECONT_MDM(1),    0x03314031},
    { UMC_RATECONT_HDD(1),    0x01005100},
    { UMC_RATECONT_MDD(1),    0x03634063},
    { UMC_RATECONT_SIO(1),    0x01005100},
    { UMC_RATECONT_GIO(1),    0x01005100},
    { UMC_RATECONT_VO1(1),    0x01005100},
    { UMC_RATECONT_VO2(1),    0x01005100},
    { UMC_RATECONT_VO0(1),    0x037A407A},
    { UMC_RATECONT_VDV(1),    0x01005100},
    { UMC_RATECONT_VPE(1),    0x03384038},
    { UMC_RATECONT_RG0(1),    0x01005100},
    { UMC_RATECONT_GR0(1),    0x01005100},
    { UMC_RATECONT_VG2(1),    0x03214021},
    { UMC_RATECONT_PCI(1),    0x01005100},
    { UMC_RATECONT_AIO(1),    0x01005100},
    { UMC_RATECONT_VDM(1),    0x03334033},
    { UMC_RATECONT_REF(1),    0x0AAB47AB},
    { UMC_RATECONT_IDS(1),    0x01005100},
    { UMC_RATECONT_ID2(1),    0x01005100},
    { UMC_RATECONT_IXM(1),    0x01005100},
    { UMC_RATECONT_VDC(1),    0x051E421E},
    { UMC_RATECONT_VDW(1),    0x03624062},
    { UMC_RATECONT_VW2(1),    0x03624062},
    { UMC_RATECONT_AR0(1),    0x01005100},
    { UMC_RATECONT_PXT(1),    0x01005100},
    { UMC_RATECONT_PXW(1),    0x01005100},
    { UMC_RATECONT_PXR(1),    0x01005100},
    { UMC_RATECONT_ICS(2),    0x01005100},
    { UMC_RATECONT_ICA(2),    0x01005100},
    { UMC_RATECONT_ICV(2),    0x01005100},
    { UMC_RATECONT_HDM(2),    0x03894089},
    { UMC_RATECONT_MDM(2),    0x01005100},
    { UMC_RATECONT_HDD(2),    0x03354035},
    { UMC_RATECONT_MDD(2),    0x01005100},
    { UMC_RATECONT_SIO(2),    0x04634163},
    { UMC_RATECONT_GIO(2),    0x01005100},
    { UMC_RATECONT_VO1(2),    0x033D403D},
    { UMC_RATECONT_VO2(2),    0x01005100},
    { UMC_RATECONT_VO0(2),    0x03624062},
    { UMC_RATECONT_VDV(2),    0x01005100},
    { UMC_RATECONT_VPE(2),    0x032E402E},
    { UMC_RATECONT_RG0(2),    0x01005100},
    { UMC_RATECONT_GR0(2),    0x01005100},
    { UMC_RATECONT_VG2(2),    0x01005100},
    { UMC_RATECONT_PCI(2),    0x01005100},
    { UMC_RATECONT_AIO(2),    0x01005100},
    { UMC_RATECONT_VDM(2),    0x01005100},
    { UMC_RATECONT_REF(2),    0x0AAB47AB},
    { UMC_RATECONT_IDS(2),    0x01005100},
    { UMC_RATECONT_ID2(2),    0x01005100},
    { UMC_RATECONT_IXM(2),    0x01005100},
    { UMC_RATECONT_VDC(2),    0x01005100},
    { UMC_RATECONT_VDW(2),    0x01005100},
    { UMC_RATECONT_VW2(2),    0x01005100},
    { UMC_RATECONT_AR0(2),    0x01005100},
    { UMC_RATECONT_PXT(2),    0x03724072},
    { UMC_RATECONT_PXW(2),    0x03664066},
    { UMC_RATECONT_PXR(2),    0x03354035},
    { UMC_MASTEROPTION_ICS(0),    0x00000004},
    { UMC_MASTEROPTION_ICA(0),    0x00000005},
    { UMC_MASTEROPTION_ICV(0),    0x00000004},
    { UMC_MASTEROPTION_HDM(0),    0x00000811},
    { UMC_MASTEROPTION_MDM(0),    0x00000810},
    { UMC_MASTEROPTION_HDD(0),    0x00000811},
    { UMC_MASTEROPTION_MDD(0),    0x00000810},
    { UMC_MASTEROPTION_SIO(0),    0x00000011},
    { UMC_MASTEROPTION_GIO(0),    0x00000011},
    { UMC_MASTEROPTION_VO1(0),    0x00000801},
    { UMC_MASTEROPTION_VO2(0),    0x00000810},
    { UMC_MASTEROPTION_VO0(0),    0x00000810},
    { UMC_MASTEROPTION_VDV(0),    0x00000810},
    { UMC_MASTEROPTION_VPE(0),    0x00000811},
    { UMC_MASTEROPTION_RG0(0),    0x00000810},
    { UMC_MASTEROPTION_GR0(0),    0x00000810},
    { UMC_MASTEROPTION_VG2(0),    0x00000810},
    { UMC_MASTEROPTION_PCI(0),    0x00000010},
    { UMC_MASTEROPTION_AIO(0),    0x00000011},
    { UMC_MASTEROPTION_VDM(0),    0x00000810},
    { UMC_MASTEROPTION_REF(0),    0x00000011},
    { UMC_MASTEROPTION_IDS(0),    0x00000011},
    { UMC_MASTEROPTION_ID2(0),    0x00000011},
    { UMC_MASTEROPTION_IXM(0),    0x00000811},
    { UMC_MASTEROPTION_VDC(0),    0x00000810},
    { UMC_MASTEROPTION_VDW(0),    0x00000811},
    { UMC_MASTEROPTION_VW2(0),    0x00000811},
    { UMC_MASTEROPTION_AR0(0),    0x00000004},
    { UMC_MASTEROPTION_PXT(0),    0x00000810},
    { UMC_MASTEROPTION_PXW(0),    0x00000810},
    { UMC_MASTEROPTION_PXR(0),    0x00000810},
    { UMC_MASTEROPTION_ICS(1),    0x00000004},
    { UMC_MASTEROPTION_ICA(1),    0x00000004},
    { UMC_MASTEROPTION_ICV(1),    0x00000004},
    { UMC_MASTEROPTION_HDM(1),    0x00000810},
    { UMC_MASTEROPTION_MDM(1),    0x00000811},
    { UMC_MASTEROPTION_HDD(1),    0x00000810},
    { UMC_MASTEROPTION_MDD(1),    0x00000811},
    { UMC_MASTEROPTION_SIO(1),    0x00000010},
    { UMC_MASTEROPTION_GIO(1),    0x00000010},
    { UMC_MASTEROPTION_VO1(1),    0x00000810},
    { UMC_MASTEROPTION_VO2(1),    0x00000810},
    { UMC_MASTEROPTION_VO0(1),    0x00000801},
    { UMC_MASTEROPTION_VDV(1),    0x00000810},
    { UMC_MASTEROPTION_VPE(1),    0x00000811},
    { UMC_MASTEROPTION_RG0(1),    0x00000810},
    { UMC_MASTEROPTION_GR0(1),    0x00000810},
    { UMC_MASTEROPTION_VG2(1),    0x00000811},
    { UMC_MASTEROPTION_PCI(1),    0x00000010},
    { UMC_MASTEROPTION_AIO(1),    0x00000010},
    { UMC_MASTEROPTION_VDM(1),    0x00000811},
    { UMC_MASTEROPTION_REF(1),    0x00000011},
    { UMC_MASTEROPTION_IDS(1),    0x00000011},
    { UMC_MASTEROPTION_ID2(1),    0x00000011},
    { UMC_MASTEROPTION_IXM(1),    0x00000810},
    { UMC_MASTEROPTION_VDC(1),    0x00000811},
    { UMC_MASTEROPTION_VDW(1),    0x00000811},
    { UMC_MASTEROPTION_VW2(1),    0x00000811},
    { UMC_MASTEROPTION_AR0(1),    0x00000004},
    { UMC_MASTEROPTION_PXT(1),    0x00000810},
    { UMC_MASTEROPTION_PXW(1),    0x00000810},
    { UMC_MASTEROPTION_PXR(1),    0x00000810},
    { UMC_MASTEROPTION_ICS(2),    0x00000004},
    { UMC_MASTEROPTION_ICA(2),    0x00000005},
    { UMC_MASTEROPTION_ICV(2),    0x00000004},
    { UMC_MASTEROPTION_HDM(2),    0x00000810},
    { UMC_MASTEROPTION_MDM(2),    0x00000810},
    { UMC_MASTEROPTION_HDD(2),    0x00000810},
    { UMC_MASTEROPTION_MDD(2),    0x00000810},
    { UMC_MASTEROPTION_SIO(2),    0x00000011},
    { UMC_MASTEROPTION_GIO(2),    0x00000010},
    { UMC_MASTEROPTION_VO1(2),    0x00000801},
    { UMC_MASTEROPTION_VO2(2),    0x00000810},
    { UMC_MASTEROPTION_VO0(2),    0x00000801},
    { UMC_MASTEROPTION_VDV(2),    0x00000810},
    { UMC_MASTEROPTION_VPE(2),    0x00000811},
    { UMC_MASTEROPTION_RG0(2),    0x00000810},
    { UMC_MASTEROPTION_GR0(2),    0x00000810},
    { UMC_MASTEROPTION_VG2(2),    0x00000810},
    { UMC_MASTEROPTION_PCI(2),    0x00000010},
    { UMC_MASTEROPTION_AIO(2),    0x00000011},
    { UMC_MASTEROPTION_VDM(2),    0x00000810},
    { UMC_MASTEROPTION_REF(2),    0x00000011},
    { UMC_MASTEROPTION_IDS(2),    0x00000011},
    { UMC_MASTEROPTION_ID2(2),    0x00000011},
    { UMC_MASTEROPTION_IXM(2),    0x00000810},
    { UMC_MASTEROPTION_VDC(2),    0x00000810},
    { UMC_MASTEROPTION_VDW(2),    0x00000810},
    { UMC_MASTEROPTION_VW2(2),    0x00000810},
    { UMC_MASTEROPTION_AR0(2),    0x00000004},
    { UMC_MASTEROPTION_PXT(2),    0x00000811},
    { UMC_MASTEROPTION_PXW(2),    0x00000811},
    { UMC_MASTEROPTION_PXR(2),    0x00000811},
    { UMC_PRIORITY_ICS(0),    0x00020000},
    { UMC_PRIORITY_ICA(0),    0x01010000},
    { UMC_PRIORITY_ICV(0),    0x02030000},
    { UMC_PRIORITY_HDM(0),    0x03000004},
    { UMC_PRIORITY_MDM(0),    0x04000015},
    { UMC_PRIORITY_HDD(0),    0x05000003},
    { UMC_PRIORITY_MDD(0),    0x06000016},
    { UMC_PRIORITY_SIO(0),    0x07000001},
    { UMC_PRIORITY_GIO(0),    0x08000002},
    { UMC_PRIORITY_VO1(0),    0x09000012},
    { UMC_PRIORITY_VO2(0),    0x0A000017},
    { UMC_PRIORITY_VO0(0),    0x0B000013},
    { UMC_PRIORITY_VDV(0),    0x0C000018},
    { UMC_PRIORITY_VPE(0),    0x0D00000A},
    { UMC_PRIORITY_RG0(0),    0x0E000010},
    { UMC_PRIORITY_GR0(0),    0x0F00000F},
    { UMC_PRIORITY_VG2(0),    0x10000019},
    { UMC_PRIORITY_PCI(0),    0x1100000E},
    { UMC_PRIORITY_AIO(0),    0x12000011},
    { UMC_PRIORITY_VDM(0),    0x1300001A},
    { UMC_PRIORITY_REF(0),    0x14000000},
    { UMC_PRIORITY_IDS(0),    0x1504000C},
    { UMC_PRIORITY_ID2(0),    0x1605000D},
    { UMC_PRIORITY_IXM(0),    0x17000008},
    { UMC_PRIORITY_VDC(0),    0x1800001B},
    { UMC_PRIORITY_VDW(0),    0x19000009},
    { UMC_PRIORITY_VW2(0),    0x1A000014},
    { UMC_PRIORITY_AR0(0),    0x1B00000B},
    { UMC_PRIORITY_PXT(0),    0x1C000006},
    { UMC_PRIORITY_PXW(0),    0x1D000005},
    { UMC_PRIORITY_PXR(0),    0x1E000007},
    { UMC_PRIORITY_ICS(1),    0x00020000},
    { UMC_PRIORITY_ICA(1),    0x01010000},
    { UMC_PRIORITY_ICV(1),    0x02030000},
    { UMC_PRIORITY_HDM(1),    0x0300000E},
    { UMC_PRIORITY_MDM(1),    0x04000004},
    { UMC_PRIORITY_HDD(1),    0x0500000F},
    { UMC_PRIORITY_MDD(1),    0x06000003},
    { UMC_PRIORITY_SIO(1),    0x07000010},
    { UMC_PRIORITY_GIO(1),    0x08000011},
    { UMC_PRIORITY_VO1(1),    0x09000012},
    { UMC_PRIORITY_VO2(1),    0x0A000013},
    { UMC_PRIORITY_VO0(1),    0x0B000007},
    { UMC_PRIORITY_VDV(1),    0x0C000014},
    { UMC_PRIORITY_VPE(1),    0x0D000005},
    { UMC_PRIORITY_RG0(1),    0x0E000008},
    { UMC_PRIORITY_GR0(1),    0x0F000009},
    { UMC_PRIORITY_VG2(1),    0x1000000D},
    { UMC_PRIORITY_PCI(1),    0x11000015},
    { UMC_PRIORITY_AIO(1),    0x12000016},
    { UMC_PRIORITY_VDM(1),    0x13000002},
    { UMC_PRIORITY_REF(1),    0x14000000},
    { UMC_PRIORITY_IDS(1),    0x15040017},
    { UMC_PRIORITY_ID2(1),    0x16050018},
    { UMC_PRIORITY_IXM(1),    0x1700000C},
    { UMC_PRIORITY_VDC(1),    0x18000006},
    { UMC_PRIORITY_VDW(1),    0x19000001},
    { UMC_PRIORITY_VW2(1),    0x1A00000B},
    { UMC_PRIORITY_AR0(1),    0x1B00000A},
    { UMC_PRIORITY_PXT(1),    0x1C000019},
    { UMC_PRIORITY_PXW(1),    0x1D00001A},
    { UMC_PRIORITY_PXR(1),    0x1E00001B},
    { UMC_PRIORITY_ICS(2),    0x00020000},
    { UMC_PRIORITY_ICA(2),    0x01010000},
    { UMC_PRIORITY_ICV(2),    0x02030000},
    { UMC_PRIORITY_HDM(2),    0x03000009},
    { UMC_PRIORITY_MDM(2),    0x0400000A},
    { UMC_PRIORITY_HDD(2),    0x0500000B},
    { UMC_PRIORITY_MDD(2),    0x0600000C},
    { UMC_PRIORITY_SIO(2),    0x07000001},
    { UMC_PRIORITY_GIO(2),    0x0800000D},
    { UMC_PRIORITY_VO1(2),    0x09000006},
    { UMC_PRIORITY_VO2(2),    0x0A00000E},
    { UMC_PRIORITY_VO0(2),    0x0B000007},
    { UMC_PRIORITY_VDV(2),    0x0C00000F},
    { UMC_PRIORITY_VPE(2),    0x0D000002},
    { UMC_PRIORITY_RG0(2),    0x0E000010},
    { UMC_PRIORITY_GR0(2),    0x0F000011},
    { UMC_PRIORITY_VG2(2),    0x10000012},
    { UMC_PRIORITY_PCI(2),    0x11000013},
    { UMC_PRIORITY_AIO(2),    0x12000014},
    { UMC_PRIORITY_VDM(2),    0x13000015},
    { UMC_PRIORITY_REF(2),    0x14000000},
    { UMC_PRIORITY_IDS(2),    0x15040016},
    { UMC_PRIORITY_ID2(2),    0x16050017},
    { UMC_PRIORITY_IXM(2),    0x17000018},
    { UMC_PRIORITY_VDC(2),    0x18000019},
    { UMC_PRIORITY_VDW(2),    0x1900001A},
    { UMC_PRIORITY_VW2(2),    0x1A00001B},
    { UMC_PRIORITY_AR0(2),    0x1B000008},
    { UMC_PRIORITY_PXT(2),    0x1C000003},
    { UMC_PRIORITY_PXW(2),    0x1D000004},
    { UMC_PRIORITY_PXR(2),    0x1E000005},
    { UMC_CHSEL_HDM,    0x03010100 },
    { UMC_CHSEL_MDM,    0x03010101 },
    { UMC_CHSEL_VDM,    0x03010101 },
    { UMC_FUNC_DATA_END, INDEX_OF_UMC_FUNC_USECASE_PXS3_BDR20G_BASE }
};



/* read write function */

static inline void write32(u32 addr, u32 data)
{
	writel(data, (void __iomem *)(u64)addr);
}

static inline u32 read32(u32 addr)
{
	return readl((void __iomem *)(u64)addr);
}


void uniphier_pxs3_umc_funcsel(void)
{

  const umc_addrdata_t *p;

  printf("Funcsel : uniphier_pxs3_umc_funcsel_180809\n");

/* 2133 */	
  for(p = comsize_table_pxs2_ld6b_freq2133; p->addr != UMC_FUNC_DATA_END; p++){
    write32(p->addr, p->data);
  }

/* LD20 */
  for(p = UMC_FUNC_USECASE_PXS3_BDR20G_BASE; p->addr != UMC_FUNC_DATA_END; p++){
    write32(p->addr, p->data);
  }
  
  /* Set Funcsel Type */
  write32(UMCDEBUGD(2), p->data);
  
  /* set rate change register */
    write32(UMC_RATE_CHANGE(0), 0x00000001);
    write32(UMC_RATE_CHANGE(1), 0x00000001);
    write32(UMC_RATE_CHANGE(2), 0x00000001);

  /* register polling ( wait until UMC_RATE_CHANGE is 0x00000000 ) */
    while(read32(UMC_RATE_CHANGE(0)));
    while(read32(UMC_RATE_CHANGE(1)));
    while(read32(UMC_RATE_CHANGE(2)));

  /* direction history arbitration mode off (temporary) */
    write32(UMC_DIR_ARB(0), 0x00000000);
    write32(UMC_DIR_ARB(1), 0x00000000);
    write32(UMC_DIR_ARB(2), 0x00000000);

  /* bank history arbitration mode off (temporary) */
    write32(UMC_BNK_ARB_MODE(0), 0x00000000);
    write32(UMC_BNK_ARB_MODE(1), 0x00000000);
    write32(UMC_BNK_ARB_MODE(2), 0x00000000);
	
}

void stio_init(int usecase){
  //int i;

  //void __iomem    *iomap_stdmac;
  //iomap_stdmac = ioremap_nocache(STDMAC_BASEADDR, 0x1000);
  //if (iomap_stdmac){

#ifdef DEBUG_STIO_INIT
  /*DEBUG*/printf("DEBUG(stio_init): usecase = 0x%08x (%d)\n",usecase,usecase);
#endif

  if(usecase == STIO_SETUP_DEFAULT){

#ifdef DEBUG_STIO_INIT
    /*DEBUG*/printf("DEBUG(stio_init): STIO_SETUP_DEFAULT setting is selected\n");
#endif
    /*** PXs2 , PXs3 ***/
    write32(STIO_PERFCNFG     ,0x00010000);// CDSTOP_PERFCNFG
    // CDSTIO_CHnCTRL2
    write32(STIO_CHnCTRL2(0),0x00000004); write32(STIO_RCnMSKCYC(0),0x00000000); //CH0_HSC1_Section0
    write32(STIO_CHnCTRL2(1),0x00010004); write32(STIO_RCnMSKCYC(1),0x00000000); //CH1_HSC1_Record0
    write32(STIO_CHnCTRL2(2),0x00010004); write32(STIO_RCnMSKCYC(1),0x00000000); //CH2_HSC1_Record1
    write32(STIO_CHnCTRL2(3),0x00010004); write32(STIO_RCnMSKCYC(1),0x00000000); //CH3_HSC1_Record2
    write32(STIO_CHnCTRL2(4),0x00020004); write32(STIO_RCnMSKCYC(2),0x00000000); //CH4_HSC1_Partial
    write32(STIO_CHnCTRL2(5),0x00030004); write32(STIO_RCnMSKCYC(3),0x00000000); //CH5_HSC1_Replay0
    write32(STIO_CHnCTRL2(6),0x00040004); write32(STIO_RCnMSKCYC(4),0x00000000); //CH6_HSC1_Replay1
    write32(STIO_CHnCTRL2(7),0x00050004); write32(STIO_RCnMSKCYC(5),0x00000000); //CH7_HSC1_Replay2
    write32(STIO_CHnCTRL2(8),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH8_HSC1_CIP-In0
    write32(STIO_CHnCTRL2(9),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH9_HSC1_CIP-Out0
    write32(STIO_CHnCTRL2(10),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH10_HSC1_CIP-In1
    write32(STIO_CHnCTRL2(11),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH11_HSC1_CIP-Out1
    write32(STIO_CHnCTRL2(12),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH12_HSC1_CIP-In2
    write32(STIO_CHnCTRL2(13),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH13_HSC1_CIP-Out2
    write32(STIO_CHnCTRL2(14),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH14_HSC1_CIP-In3
    write32(STIO_CHnCTRL2(15),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH15_HSC1_CIP-Out3
    write32(STIO_CHnCTRL2(16),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH16_HSC1_CIP-In4
    write32(STIO_CHnCTRL2(17),0x000a0004); write32(STIO_RCnMSKCYC(10),0x00000000); //CH17_HSC1_CIP-Out4
    write32(STIO_CHnCTRL2(18),0x00090004); write32(STIO_RCnMSKCYC(9),0x00000000); //CH18_HSC1_ACE
    write32(STIO_CHnCTRL2(19),0x00010004); write32(STIO_RCnMSKCYC(1),0x00000000); //CH19_HSC1_Record3
    write32(STIO_CHnCTRL2(20),0x00010004); write32(STIO_RCnMSKCYC(1),0x00000000); //CH20_HSC1_Record4
    write32(STIO_CHnCTRL2(21),0x00010004); write32(STIO_RCnMSKCYC(1),0x00000000); //CH21_HSC1_Record5
    write32(STIO_CHnCTRL2(22),0x00060004); write32(STIO_RCnMSKCYC(6),0x00000000); //CH22_HSC1_Replay3
    write32(STIO_CHnCTRL2(23),0x00070004); write32(STIO_RCnMSKCYC(7),0x00000000); //CH23_HSC1_Replay4
    write32(STIO_CHnCTRL2(24),0x00080004); write32(STIO_RCnMSKCYC(8),0x00000000); //CH24_HSC1_Replay5
    write32(STIO_CHnCTRL2(25),0x00000004); write32(STIO_RCnMSKCYC(0),0x00000000); //CH25_HSC1_Section1
    write32(STIO_CHnCTRL2(26),0x00000004); write32(STIO_RCnMSKCYC(0),0x00000000); //CH26_HSC1_Section2
    write32(STIO_CHnCTRL2(164),0x00000004); write32(STIO_RCnMSKCYC(332),0x00000000); //CH37_HSC2_Section0
    write32(STIO_CHnCTRL2(165),0x00010004); write32(STIO_RCnMSKCYC(333),0x00000000); //CH38_HSC2_Record0
    write32(STIO_CHnCTRL2(166),0x00010004); write32(STIO_RCnMSKCYC(333),0x00000000); //CH39_HSC2_Record1
    write32(STIO_CHnCTRL2(167),0x00010004); write32(STIO_RCnMSKCYC(333),0x00000000); //CH40_HSC2_Record2
    write32(STIO_CHnCTRL2(168),0x00020004); write32(STIO_RCnMSKCYC(334),0x00000000); //CH41_HSC2_Partial
    write32(STIO_CHnCTRL2(169),0x00030004); write32(STIO_RCnMSKCYC(335),0x00000000); //CH42_HSC2_Replay0
    write32(STIO_CHnCTRL2(170),0x00040004); write32(STIO_RCnMSKCYC(336),0x00000000); //CH43_HSC2_Replay1
    write32(STIO_CHnCTRL2(171),0x00050004); write32(STIO_RCnMSKCYC(337),0x00000000); //CH44_HSC2_Replay2
    write32(STIO_CHnCTRL2(172),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH45_HSC2_CIP-In0
    write32(STIO_CHnCTRL2(173),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH46_HSC2_CIP-Out0
    write32(STIO_CHnCTRL2(174),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH47_HSC2_CIP-In1
    write32(STIO_CHnCTRL2(175),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH48_HSC2_CIP-Out1
    write32(STIO_CHnCTRL2(176),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH49_HSC2_CIP-In2
    write32(STIO_CHnCTRL2(177),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH50_HSC2_CIP-Out2
    write32(STIO_CHnCTRL2(178),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH51_HSC2_CIP-In3
    write32(STIO_CHnCTRL2(179),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH52_HSC2_CIP-Out3
    write32(STIO_CHnCTRL2(180),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH53_HSC2_CIP-In4
    write32(STIO_CHnCTRL2(181),0x000a0004); write32(STIO_RCnMSKCYC(342),0x00000000); //CH54_HSC2_CIP-Out4
    write32(STIO_CHnCTRL2(182),0x00090004); write32(STIO_RCnMSKCYC(341),0x00000000); //CH55_HSC2_ACE
    write32(STIO_CHnCTRL2(183),0x00010004); write32(STIO_RCnMSKCYC(333),0x00000000); //CH56_HSC2_Record3
    write32(STIO_CHnCTRL2(184),0x00010004); write32(STIO_RCnMSKCYC(333),0x00000000); //CH57_HSC2_Record4
    write32(STIO_CHnCTRL2(185),0x00010004); write32(STIO_RCnMSKCYC(333),0x00000000); //CH58_HSC2_Record5
    write32(STIO_CHnCTRL2(186),0x00060004); write32(STIO_RCnMSKCYC(338),0x00000000); //CH59_HSC2_Replay3
    write32(STIO_CHnCTRL2(187),0x00070004); write32(STIO_RCnMSKCYC(339),0x00000000); //CH60_HSC2_Replay4
    write32(STIO_CHnCTRL2(188),0x00080004); write32(STIO_RCnMSKCYC(340),0x00000000); //CH61_HSC2_Replay5
    write32(STIO_CHnCTRL2(189),0x00000004); write32(STIO_RCnMSKCYC(332),0x00000000); //CH62_HSC2_Section1
    write32(STIO_CHnCTRL2(190),0x00000004); write32(STIO_RCnMSKCYC(332),0x00000000); //CH63_HSC2_Section2

    write32(STIO_CHnCTRL2(40),0x00000004); write32(STIO_RCnMSKCYC(22),0x00000000); //CH83_RLE_PG0-R
    write32(STIO_CHnCTRL2(41),0x00000004); write32(STIO_RCnMSKCYC(23),0x00000000); //CH84_RLE_IG0-R
    write32(STIO_CHnCTRL2(42),0x00000004); write32(STIO_RCnMSKCYC(24),0x00000000); //CH85_RLE_PG0-W
    write32(STIO_CHnCTRL2(43),0x00000004); write32(STIO_RCnMSKCYC(25),0x00000000); //CH86_RLE_IG0-W
    write32(STIO_CHnCTRL2(44),0x00000004); write32(STIO_RCnMSKCYC(26),0x00000000); //CH87_RLE_PG1-R
    write32(STIO_CHnCTRL2(45),0x00000004); write32(STIO_RCnMSKCYC(27),0x00000000); //CH88_RLE_IG1-R
    write32(STIO_CHnCTRL2(46),0x00000004); write32(STIO_RCnMSKCYC(28),0x00000000); //CH89_RLE_PG1-W
    write32(STIO_CHnCTRL2(47),0x00000004); write32(STIO_RCnMSKCYC(29),0x00000000); //CH90_RLE_IG1-W
  } else if(usecase == STIO_SETUP_USECASE_SHARED){
#ifdef DEBUG_STIO_INIT
    /*DEBUG*/printf("DEBUG(stio_init): STIO_SETUP_USECASE_SHARED setting is selected\n");
#endif
    /*** PXs2 , PXs3 ***/
    write32(STIO_PERFCNFG     ,0x00010022);// CDSTOP_PERFCNFG
    // CDSTIO_CHnCTRL2
    write32(STIO_CHnCTRL2(0),0x00000001); write32(STIO_RCnMSKCYC(0),0x00000000); //CH0_HSC1_Section0
    write32(STIO_CHnCTRL2(1),0x00010002); write32(STIO_RCnMSKCYC(1),0x00000000); //CH1_HSC1_Record0
    write32(STIO_CHnCTRL2(2),0x00010002); write32(STIO_RCnMSKCYC(1),0x00000000); //CH2_HSC1_Record1
    write32(STIO_CHnCTRL2(3),0x00010002); write32(STIO_RCnMSKCYC(1),0x00000000); //CH3_HSC1_Record2
    write32(STIO_CHnCTRL2(4),0x00020003); write32(STIO_RCnMSKCYC(2),0x00000000); //CH4_HSC1_Partial
    write32(STIO_CHnCTRL2(5),0x00030002); write32(STIO_RCnMSKCYC(3),0x00000000); //CH5_HSC1_Replay0
    write32(STIO_CHnCTRL2(6),0x00040002); write32(STIO_RCnMSKCYC(4),0x00000000); //CH6_HSC1_Replay1
    write32(STIO_CHnCTRL2(7),0x00050002); write32(STIO_RCnMSKCYC(5),0x00000000); //CH7_HSC1_Replay2
    write32(STIO_CHnCTRL2(8),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH8_HSC1_CIP-In0
    write32(STIO_CHnCTRL2(9),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH9_HSC1_CIP-Out0
    write32(STIO_CHnCTRL2(10),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH10_HSC1_CIP-In1
    write32(STIO_CHnCTRL2(11),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH11_HSC1_CIP-Out1
    write32(STIO_CHnCTRL2(12),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH12_HSC1_CIP-In2
    write32(STIO_CHnCTRL2(13),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH13_HSC1_CIP-Out2
    write32(STIO_CHnCTRL2(14),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH14_HSC1_CIP-In3
    write32(STIO_CHnCTRL2(15),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH15_HSC1_CIP-Out3
    write32(STIO_CHnCTRL2(16),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH16_HSC1_CIP-In4
    write32(STIO_CHnCTRL2(17),0x000a0003); write32(STIO_RCnMSKCYC(10),0x00000000); //CH17_HSC1_CIP-Out4
    write32(STIO_CHnCTRL2(18),0x00090003); write32(STIO_RCnMSKCYC(9),0x00000000); //CH18_HSC1_ACE
    write32(STIO_CHnCTRL2(19),0x00010002); write32(STIO_RCnMSKCYC(1),0x00000000); //CH19_HSC1_Record3
    write32(STIO_CHnCTRL2(20),0x00010002); write32(STIO_RCnMSKCYC(1),0x00000000); //CH20_HSC1_Record4
    write32(STIO_CHnCTRL2(21),0x00010002); write32(STIO_RCnMSKCYC(1),0x00000000); //CH21_HSC1_Record5
    write32(STIO_CHnCTRL2(22),0x00060002); write32(STIO_RCnMSKCYC(6),0x00000000); //CH22_HSC1_Replay3
    write32(STIO_CHnCTRL2(23),0x00070002); write32(STIO_RCnMSKCYC(7),0x00000000); //CH23_HSC1_Replay4
    write32(STIO_CHnCTRL2(24),0x00080002); write32(STIO_RCnMSKCYC(8),0x00000000); //CH24_HSC1_Replay5
    write32(STIO_CHnCTRL2(25),0x00000001); write32(STIO_RCnMSKCYC(0),0x00000000); //CH25_HSC1_Section1
    write32(STIO_CHnCTRL2(26),0x00000001); write32(STIO_RCnMSKCYC(0),0x00000000); //CH26_HSC1_Section2
    write32(STIO_CHnCTRL2(164),0x00000001); write32(STIO_RCnMSKCYC(332),0x00000000); //CH37_HSC2_Section0
    write32(STIO_CHnCTRL2(165),0x00010002); write32(STIO_RCnMSKCYC(333),0x00000000); //CH38_HSC2_Record0
    write32(STIO_CHnCTRL2(166),0x00010002); write32(STIO_RCnMSKCYC(333),0x00000000); //CH39_HSC2_Record1
    write32(STIO_CHnCTRL2(167),0x00010002); write32(STIO_RCnMSKCYC(333),0x00000000); //CH40_HSC2_Record2
    write32(STIO_CHnCTRL2(168),0x00020003); write32(STIO_RCnMSKCYC(334),0x00000000); //CH41_HSC2_Partial
    write32(STIO_CHnCTRL2(169),0x00030002); write32(STIO_RCnMSKCYC(335),0x00000000); //CH42_HSC2_Replay0
    write32(STIO_CHnCTRL2(170),0x00040002); write32(STIO_RCnMSKCYC(336),0x00000000); //CH43_HSC2_Replay1
    write32(STIO_CHnCTRL2(171),0x00050002); write32(STIO_RCnMSKCYC(337),0x00000000); //CH44_HSC2_Replay2
    write32(STIO_CHnCTRL2(172),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH45_HSC2_CIP-In0
    write32(STIO_CHnCTRL2(173),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH46_HSC2_CIP-Out0
    write32(STIO_CHnCTRL2(174),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH47_HSC2_CIP-In1
    write32(STIO_CHnCTRL2(175),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH48_HSC2_CIP-Out1
    write32(STIO_CHnCTRL2(176),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH49_HSC2_CIP-In2
    write32(STIO_CHnCTRL2(177),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH50_HSC2_CIP-Out2
    write32(STIO_CHnCTRL2(178),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH51_HSC2_CIP-In3
    write32(STIO_CHnCTRL2(179),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH52_HSC2_CIP-Out3
    write32(STIO_CHnCTRL2(180),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH53_HSC2_CIP-In4
    write32(STIO_CHnCTRL2(181),0x000a0003); write32(STIO_RCnMSKCYC(342),0x00000000); //CH54_HSC2_CIP-Out4
    write32(STIO_CHnCTRL2(182),0x00090003); write32(STIO_RCnMSKCYC(341),0x00000000); //CH55_HSC2_ACE
    write32(STIO_CHnCTRL2(183),0x00010002); write32(STIO_RCnMSKCYC(333),0x00000000); //CH56_HSC2_Record3
    write32(STIO_CHnCTRL2(184),0x00010002); write32(STIO_RCnMSKCYC(333),0x00000000); //CH57_HSC2_Record4
    write32(STIO_CHnCTRL2(185),0x00010002); write32(STIO_RCnMSKCYC(333),0x00000000); //CH58_HSC2_Record5
    write32(STIO_CHnCTRL2(186),0x00060002); write32(STIO_RCnMSKCYC(338),0x00000000); //CH59_HSC2_Replay3
    write32(STIO_CHnCTRL2(187),0x00070002); write32(STIO_RCnMSKCYC(339),0x00000000); //CH60_HSC2_Replay4
    write32(STIO_CHnCTRL2(188),0x00080002); write32(STIO_RCnMSKCYC(340),0x00000000); //CH61_HSC2_Replay5
    write32(STIO_CHnCTRL2(189),0x00000001); write32(STIO_RCnMSKCYC(332),0x00000000); //CH62_HSC2_Section1
    write32(STIO_CHnCTRL2(190),0x00000001); write32(STIO_RCnMSKCYC(332),0x00000000); //CH63_HSC2_Section2

    write32(STIO_CHnCTRL2(40),0x00000003); write32(STIO_RCnMSKCYC(22),0x00000000); //CH83_RLE_PG0-R
    write32(STIO_CHnCTRL2(41),0x00000003); write32(STIO_RCnMSKCYC(23),0x00000000); //CH84_RLE_IG0-R
    write32(STIO_CHnCTRL2(42),0x00000003); write32(STIO_RCnMSKCYC(24),0x00000000); //CH85_RLE_PG0-W
    write32(STIO_CHnCTRL2(43),0x00000003); write32(STIO_RCnMSKCYC(25),0x00000000); //CH86_RLE_IG0-W
    write32(STIO_CHnCTRL2(44),0x00000003); write32(STIO_RCnMSKCYC(26),0x00000000); //CH87_RLE_PG1-R
    write32(STIO_CHnCTRL2(45),0x00000003); write32(STIO_RCnMSKCYC(27),0x00000000); //CH88_RLE_IG1-R
    write32(STIO_CHnCTRL2(46),0x00000003); write32(STIO_RCnMSKCYC(28),0x00000000); //CH89_RLE_PG1-W
    write32(STIO_CHnCTRL2(47),0x00000003); write32(STIO_RCnMSKCYC(29),0x00000000); //CH90_RLE_IG1-W
  } else if(usecase == STIO_SETUP_MAXLOAD_SDCARD){

#ifdef DEBUG_STIO_INIT
    /*DEBUG*/printf("DEBUG(stio_init): STIO_SETUP_MAXLOAD_SDCARD setting is selected\n");
#endif

  } else if(usecase == STIO_SETUP_MAXLOAD_MIO_NOREALTIME){
#ifdef DEBUG_STIO_INIT
    /*DEBUG*/printf("DEBUG(stio_init): STIO_SETUP_MAXLOAD_MIO_NOREALTIME setting is selected\n");
#endif

  } else {
#if 0/* remove printf */
    printf("Error : Invalid argument of stio_init function!!!\n");
#endif/* remove printf */
  }
  //}/* ipremap() */
  //else{
  //    pr_err(" STDMAC_BASEADDR %#08x can't ioremap.\n", STDMAC_BASEADDR);
  //}
}

